@@ -54,7 +54,7 @@ do i=1,6
 end do
 call minf_nm(1,zm,n2,x,maxit,iter,eps)
 ! fit everything together
-if (npole.gt.1) then
+if (npole > 1) then
   do i=1,n2
     x(i,i+1)=x(i,1)+0.1d0
   end do
