@@ -18,7 +18,7 @@ if ((abs(fsmtype) == 1).or.(abs(fsmtype) == 3)) then
       npc=npcmt(is)
       bsmt(1:npc,ias,idm)=bsmt(1:npc,ias,idm)+t1
     end do
-    bsir(1:ngtot,idm)=bsir(1:ngtot,idm)+t1*cfunir(1:ngtot)
+    bsirc(1:ngtc,idm)=bsirc(1:ngtc,idm)+t1*cfrc(1:ngtc)
   end do
 end if
 ! add the muffin-tin fields
