@@ -8,13 +8,12 @@ use modmain
 implicit none
 ! local variables
 integer is,nlo,l,io
-if (.not.lorbcnd) return
 ! add conduction local-orbitals to each species
 do is=1,nspecies
   nlo=nlorb(is)
   do l=0,lmaxo
     nlo=nlo+1
-    if (nlo.gt.maxlorb) then
+    if (nlo > maxlorb) then
       write(*,*)
       write(*,'("Error(addlorbcnd): nlorb too large : ",I8)') nlo
       write(*,'(" for species ",I4)') is
