@@ -78,9 +78,9 @@ wd=wint(2)-wint(1)
 dw=wd/dble(nw)
 dwi=1.d0/dw
 w1=wint(1)*dwi
-g(:)=0.d0
+g(1:nw)=0.d0
 call holdthd(nk,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(f0,f1,e0,e1) &
 !$OMP PRIVATE(f00,f01,f10,f11) &
 !$OMP PRIVATE(e00,e01,e10,e11) &
@@ -89,8 +89,9 @@ call holdthd(nk,nthd)
 !$OMP PRIVATE(i100,i101,i110,i111) &
 !$OMP PRIVATE(t1,t2,i,iw) &
 !$OMP REDUCTION(+:g) &
-!$OMP NUM_THREADS(nthd)
-!$OMP DO COLLAPSE(3)
+!$OMP SCHEDULE(DYNAMIC) &
+!$OMP NUM_THREADS(nthd) &
+!$OMP COLLAPSE(3)
 do j1=0,ngridk(1)-1
   do j2=0,ngridk(2)-1
     do j3=0,ngridk(3)-1
@@ -104,23 +105,23 @@ do j1=0,ngridk(1)-1
       do i1=0,nsk(1)-1
         t2=dble(i1)/dble(nsk(1))
         t1=1.d0-t2
-        f00(:)=f(:,i000)*t1+f(:,i100)*t2
-        f01(:)=f(:,i001)*t1+f(:,i101)*t2
-        f10(:)=f(:,i010)*t1+f(:,i110)*t2
-        f11(:)=f(:,i011)*t1+f(:,i111)*t2
+        f00(1:n)=f(1:n,i000)*t1+f(1:n,i100)*t2
+        f01(1:n)=f(1:n,i001)*t1+f(1:n,i101)*t2
+        f10(1:n)=f(1:n,i010)*t1+f(1:n,i110)*t2
+        f11(1:n)=f(1:n,i011)*t1+f(1:n,i111)*t2
         t1=t1*dwi
         t2=t2*dwi
-        e00(:)=e(:,i000)*t1+e(:,i100)*t2-w1
-        e01(:)=e(:,i001)*t1+e(:,i101)*t2-w1
-        e10(:)=e(:,i010)*t1+e(:,i110)*t2-w1
-        e11(:)=e(:,i011)*t1+e(:,i111)*t2-w1
+        e00(1:n)=e(1:n,i000)*t1+e(1:n,i100)*t2-w1
+        e01(1:n)=e(1:n,i001)*t1+e(1:n,i101)*t2-w1
+        e10(1:n)=e(1:n,i010)*t1+e(1:n,i110)*t2-w1
+        e11(1:n)=e(1:n,i011)*t1+e(1:n,i111)*t2-w1
         do i2=0,nsk(2)-1
           t2=dble(i2)/dble(nsk(2))
           t1=1.d0-t2
-          f0(:)=f00(:)*t1+f10(:)*t2
-          f1(:)=f01(:)*t1+f11(:)*t2
-          e0(:)=e00(:)*t1+e10(:)*t2
-          e1(:)=e01(:)*t1+e11(:)*t2
+          f0(1:n)=f00(1:n)*t1+f10(1:n)*t2
+          f1(1:n)=f01(1:n)*t1+f11(1:n)*t2
+          e0(1:n)=e00(1:n)*t1+e10(1:n)*t2
+          e1(1:n)=e01(1:n)*t1+e11(1:n)*t2
           do i3=0,nsk(3)-1
             t2=dble(i3)/dble(nsk(3))
             t1=1.d0-t2
@@ -134,13 +135,12 @@ do j1=0,ngridk(1)-1
     end do
   end do
 end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
 ! normalise function
 t1=dw*dble(nk)*dble(nsk(1)*nsk(2)*nsk(3))
 t1=1.d0/t1
-g(:)=t1*g(:)
+g(1:nw)=t1*g(1:nw)
 ! smooth output function if required
 if (nsm > 0) call fsmooth(nsm,nw,g)
 end subroutine
