@@ -27,7 +27,7 @@ implicit none
 integer is,js
 real(8) dmin,t1,t2
 real(8) rmtp(nspecies)
-if (nspecies <= 0) return
+if (nspecies < 1) return
 ! store previous muffin-tin radii
 rmtp(1:nspecies)=rmt(1:nspecies)
 ! restore original muffin-tin radii read from species files if required
