@@ -17,18 +17,16 @@ real(8), allocatable :: grfmt(:,:,:,:),grfir(:,:,:)
 allocate(grfmt(npmtmax,natmtot,3,3),grfir(ngtot,3,3))
 ! compute the gradients
 call holdthd(3,nthd)
-!$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(i,ias,is,np) &
 !$OMP NUM_THREADS(nthd)
+!$OMP DO SCHEDULE(DYNAMIC)
 do i=1,3
   call gradrf(rvfmt(:,:,i),rvfir(:,i),grfmt(:,:,:,i),grfir(:,:,i))
 end do
-!$OMP END PARALLEL DO
-call freethd(nthd)
+!$OMP END DO
 ! determine the muffin-tin and interstitial curl
-call holdthd(2,nthd)
-!$OMP PARALLEL SECTIONS DEFAULT(SHARED) &
-!$OMP PRIVATE(ias,is,np) &
-!$OMP NUM_THREADS(nthd)
+!$OMP SECTIONS
 !$OMP SECTION
 do ias=1,natmtot
   is=idxis(ias)
@@ -38,10 +36,11 @@ do ias=1,natmtot
   curlmt(1:np,ias,3)=grfmt(1:np,ias,1,2)-grfmt(1:np,ias,2,1)
 end do
 !$OMP SECTION
-curlir(:,1)=grfir(:,2,3)-grfir(:,3,2)
-curlir(:,2)=grfir(:,3,1)-grfir(:,1,3)
-curlir(:,3)=grfir(:,1,2)-grfir(:,2,1)
-!$OMP END PARALLEL SECTIONS
+curlir(1:ngtot,1)=grfir(1:ngtot,2,3)-grfir(1:ngtot,3,2)
+curlir(1:ngtot,2)=grfir(1:ngtot,3,1)-grfir(1:ngtot,1,3)
+curlir(1:ngtot,3)=grfir(1:ngtot,1,2)-grfir(1:ngtot,2,1)
+!$OMP END SECTIONS
+!$OMP END PARALLEL
 call freethd(nthd)
 deallocate(grfmt,grfir)
 end subroutine
