@@ -46,7 +46,7 @@ call hmlfv(nmq,ngpq,igpqig,vgpqc,apwalmq,h)
 call olpfv(nmq,ngpq,igpqig,apwalmq,o)
 !$OMP END PARALLEL SECTIONS
 call freethd(nthd)
-! solve the generalised eigenvalue problem (H - e_j O)|v_j> = 0
+! solve the generalised eigenvalue problem (H - eⱼ O)|vⱼ> = 0
 ! (note: these are also the eigenvalues/vectors of O⁻¹ H )
 lwork=2*nmq
 allocate(w(nmq),rwork(3*nmq),work(lwork))
@@ -66,7 +66,9 @@ call holdthd(2,nthd)
 !$OMP PRIVATE(ias,is) &
 !$OMP NUM_THREADS(nthd)
 !$OMP SECTION
-dh(:,:)=0.d0
+call dhmlistl(ngp,ngpq,igpig,igpqig,vgpc,vgpqc,nmq,dh)
+dh(ngpq+1:nmq,1:ngp)=0.d0
+dh(1:nmq,ngp+1:nm)=0.d0
 do ias=1,natmtot
   is=idxis(ias)
   call dhmlaa(is,ias,ngp,ngpq,apwalm(:,:,:,ias),apwalmq(:,:,:,ias),dapwalm, &
@@ -75,22 +77,22 @@ do ias=1,natmtot
    dapwalmq,nmq,dh)
   call dhmllolo(is,ias,ngp,ngpq,nmq,dh)
 end do
-call dhmlistl(ngp,ngpq,igpig,igpqig,vgpc,vgpqc,nmq,dh)
 !$OMP SECTION
-od(:,:)=0.d0
+call dolpistl(ngp,ngpq,igpig,igpqig,nmq,od)
+od(ngpq+1:nmq,1:ngp)=0.d0
+od(1:nmq,ngp+1:nm)=0.d0
 do ias=1,natmtot
   is=idxis(ias)
   call dolpaa(is,ias,ngp,ngpq,apwalm(:,:,:,ias),apwalmq(:,:,:,ias),dapwalm, &
    dapwalmq,nmq,od)
   call dolpalo(is,ias,ngp,ngpq,dapwalm,dapwalmq,nmq,od)
 end do
-call dolpistl(ngp,ngpq,igpig,igpqig,nmq,od)
 !$OMP END PARALLEL SECTIONS
 call freethd(nthd)
 allocate(x(nmq),y(nmq))
 ! loop over states
 do jst=1,nstfv
-! compute |dv_j> = V (e_j - D)⁻¹ V† (dH - e_j dO)|v_j>
+! compute |dvⱼ> = V (eⱼ - D)⁻¹ V† (dH - eⱼ dO)|vⱼ>
   z1=-evalfv(jst)
   call zgemv('N',nmq,nm,z1,od,nmq,evecfv(:,jst),1,zzero,x,1)
   call zgemv('N',nmq,nm,zone,dh,nmq,evecfv(:,jst),1,zone,x,1)
