@@ -30,11 +30,11 @@ do ias=1,natmtot
             do lm2=l2**2+1,(l2+1)**2
               i1=lmmaxi*(nri-1)+lm2
               zsm=sum(apwfr(1:nri,1,io,l1,ias)*apwfr(1:nri,1,jo,l3,ias) &
-               *wrmt(1:nri,is)*dvsmt(lm2:i1:lmmaxi,ias))
+               *wr2mt(1:nri,is)*dvsmt(lm2:i1:lmmaxi,ias))
               i0=i1+lmmaxi
               i1=lmmaxo*(nr-iro)+i0
               zsm=zsm+sum(apwfr(iro:nr,1,io,l1,ias)*apwfr(iro:nr,1,jo,l3,ias) &
-               *wrmt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
+               *wr2mt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
               dhaa(lm2,jo,l3,io,l1,ias)=zsm
             end do
           end do
@@ -43,7 +43,7 @@ do ias=1,natmtot
               i0=lmmaxi*nri+lm2
               i1=lmmaxo*(nr-iro)+i0
               zsm=sum(apwfr(iro:nr,1,io,l1,ias)*apwfr(iro:nr,1,jo,l3,ias) &
-               *wrmt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
+               *wr2mt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
               dhaa(lm2,jo,l3,io,l1,ias)=zsm
             end do
           end do
@@ -62,11 +62,11 @@ do ias=1,natmtot
           do lm2=l2**2+1,(l2+1)**2
             i1=lmmaxi*(nri-1)+lm2
             zsm=sum(lofr(1:nri,1,ilo,ias)*apwfr(1:nri,1,io,l3,ias) &
-             *wrmt(1:nri,is)*dvsmt(lm2:i1:lmmaxi,ias))
+             *wr2mt(1:nri,is)*dvsmt(lm2:i1:lmmaxi,ias))
             i0=i1+lmmaxi
             i1=lmmaxo*(nr-iro)+i0
             zsm=zsm+sum(lofr(iro:nr,1,ilo,ias)*apwfr(iro:nr,1,io,l3,ias) &
-             *wrmt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
+             *wr2mt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
             dhloa(lm2,io,l3,ilo,ias)=zsm
           end do
         end do
@@ -75,7 +75,7 @@ do ias=1,natmtot
             i0=lmmaxi*nri+lm2
             i1=lmmaxo*(nr-iro)+i0
             zsm=sum(lofr(iro:nr,1,ilo,ias)*apwfr(iro:nr,1,io,l3,ias) &
-             *wrmt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
+             *wr2mt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
             dhloa(lm2,io,l3,ilo,ias)=zsm
           end do
         end do
@@ -92,12 +92,12 @@ do ias=1,natmtot
       do l2=0,lmaxi
         do lm2=l2**2+1,(l2+1)**2
           i1=lmmaxi*(nri-1)+lm2
-          zsm=sum(lofr(1:nri,1,ilo,ias)*lofr(1:nri,1,jlo,ias)*wrmt(1:nri,is) &
+          zsm=sum(lofr(1:nri,1,ilo,ias)*lofr(1:nri,1,jlo,ias)*wr2mt(1:nri,is) &
            *dvsmt(lm2:i1:lmmaxi,ias))
           i0=i1+lmmaxi
           i1=lmmaxo*(nr-iro)+i0
           zsm=zsm+sum(lofr(iro:nr,1,ilo,ias)*lofr(iro:nr,1,jlo,ias) &
-           *wrmt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
+           *wr2mt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
           dhlolo(lm2,jlo,ilo,ias)=zsm
         end do
       end do
@@ -105,8 +105,8 @@ do ias=1,natmtot
         do lm2=l2**2+1,(l2+1)**2
           i0=lmmaxi*nri+lm2
           i1=lmmaxo*(nr-iro)+i0
-          zsm=sum(lofr(iro:nr,1,ilo,ias)*lofr(iro:nr,1,jlo,ias)*wrmt(iro:nr,is)&
-           *dvsmt(i0:i1:lmmaxo,ias))
+          zsm=sum(lofr(iro:nr,1,ilo,ias)*lofr(iro:nr,1,jlo,ias) &
+           *wr2mt(iro:nr,is)*dvsmt(i0:i1:lmmaxo,ias))
           dhlolo(lm2,jlo,ilo,ias)=zsm
         end do
       end do
