@@ -14,13 +14,15 @@ complex(8), intent(out) :: dvv(n,n),duv(n,n)
 real(8), intent(out) :: vn(n)
 ! local variables
 integer i
+! external functions
+real(8), external :: dznrm2
 ! normal fermionic density matrix VV†
 call zgemm('N','C',n,n,n,(1.d0,0.d0),v,n,v,n,(0.d0,0.d0),dvv,n)
 do i=1,n
 ! store the V-norm
-  vn(i)=dot_product(v(:,i),v(:,i))
+  vn(i)=dznrm2(n,v(:,i),1)**2
 ! subtract unperturbed density matrix
-  if (e(i).le.ef) dvv(i,i)=dvv(i,i)-1.d0
+  if (e(i) <= ef) dvv(i,i)=dvv(i,i)-1.d0
 end do
 ! anomalous density matrix UV†
 call zgemm('N','C',n,n,n,(1.d0,0.d0),u,n,v,n,(0.d0,0.d0),duv,n)
