@@ -17,11 +17,10 @@ complex(8), intent(in) :: dapwalmq(ngkmax,apwordmax,lmmaxapw)
 integer, intent(in) :: ld
 complex(8), intent(inout) :: od(*)
 ! local variables
-integer lmo,io,l,lm,i
+integer io,l,lm,i
 ! automatic arrays
 complex(8) a(lmoapw(is),ngpq),b(lmoapw(is),ngp)
 if (ias /= iasph) return
-lmo=lmoapw(is)
 i=0
 do l=0,lmaxapw
   do lm=l**2+1,(l+1)**2
@@ -32,7 +31,7 @@ do l=0,lmaxapw
     end do
   end do
 end do
-call zmctm(lmo,ngpq,ngp,a,b,ld,od)
+call zmmab(lmoapw(is),ngpq,ngp,a,b,ld,od)
 i=0
 do l=0,lmaxapw
   do lm=l**2+1,(l+1)**2
@@ -43,6 +42,6 @@ do l=0,lmaxapw
     end do
   end do
 end do
-call zmctm(lmo,ngpq,ngp,a,b,ld,od)
+call zmmab(lmoapw(is),ngpq,ngp,a,b,ld,od)
 end subroutine
 
