@@ -79,8 +79,7 @@ if (ramdisk) then
     write(*,'("RAM disk enabled")')
     if (.not.wrtdsk) then
       write(*,*)
-      write(*,'("Warning(elk): some direct access files may not be written to &
-       &disk")')
+      write(*,'("Info(elk): some direct access files are not written to disk")')
     end if
   end if
 else
@@ -240,6 +239,10 @@ do itask=1,ntasks
     call writestress
   case(450)
     call genafieldt
+  case(455)
+    call writeafpdt
+  case(456)
+    call writeefieldw
   case(460,461,462,463)
     call tddft
   case(471)
@@ -304,7 +307,7 @@ call mpi_finalize(ierror)
 end program
 
 !BOI
-! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 10.2.4}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
+! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 10.4.5}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
 ! !AUTHORS: {\sc J. K. Dewhurst, S. Sharma} \\ {\sc L. Nordstr\"{o}m, F. Cricchio, O. Gr\aa n\"{a}s} \\ {\sc E. K. U. Gross}
 ! !AFFILIATION:
 ! !INTRODUCTION: Introduction
@@ -677,6 +680,17 @@ end program
 !   {\tt avec(3)} & third lattice vector & real(3) & $(0.0,0.0,1.0)$}
 !   Lattice vectors of the crystal in atomic units (Bohr).
 !
+!   \block{avecref}{
+!   {\tt avecref(1)} & first reference lattice vector, etc. & real(3) &
+!    $(0.0,0.0,0.0)$}
+!   Reference lattice vectors for calculating the ${\bf G}$-vector grid and
+!   derived quantities. If any of these elements are non-zero then the code
+!   computes the corresponding reciprocal lattice vectors and set of
+!   ${\bf G}$-vectors. These are then transformed to be identical to those
+!   calculated with {\tt avec}. The purpose of this is to enable accurate
+!   energy-volume curves, where the number of grid points should remain fixed
+!   for all volumes.
+!
 !   \block{beta0}{
 !   {\tt beta0} & adaptive mixing parameter & real & $0.05$}
 !   This determines how much of the potential from the previous self-consistent
@@ -704,6 +718,12 @@ end program
 !   {\tt bfcmt} vectors in the {\tt atoms} block. Collinear calculations are
 !   more efficient if the field is applied in the $z$-direction.
 !
+!   \block{bfielduc}{
+!   {\tt bfielduc} & global external magnetic field in Cartesian coordinates &
+!    real(3) & $(0.0,0.0,0.0)$}
+!   As with {\tt bfieldc} but applied only in the ultracell during an ultra
+!   long-range calculation.
+!
 !   \block{broydpm}{
 !   {\tt broydpm} & Broyden mixing parameters $\alpha$ and $w_0$ & real &
 !    $(0.4,0.15)$}
@@ -1086,6 +1106,14 @@ end program
 !   then the density and potential file, {\tt STATE.OUT}, will {\bf not} be
 !   written to disk at the end of the loop. See {\tt epspot}.
 !
+!   \block{mixsave}{
+!   {\tt mixsave} & {\tt .true.} if the mixer work array is to be saved during a
+!    ground-state run & logical & {\tt .false.}}
+!   If {\tt mixsave} is {\tt .true.}, then the mixer work array is saved to
+!   {\tt MIXWORK.OUT} every {\tt nwrite} iterations and at the end of the
+!   self-consistent loop. This array is subsequently read in at the beginning of
+!   a restarted calculation in order to improve convergence.
+!
 !   \block{mixtype}{
 !   {\tt mixtype } & type of mixing required for the potential & integer & 3}
 !   Currently implemented are:
@@ -1104,8 +1132,8 @@ end program
 !   \block{molecule}{
 !   {\tt molecule} & {\tt .true.} if the system is an isolated molecule &
 !    logical & {\tt .false.}}
-!   If {\tt molecule} is {\tt .true.}, then the atomic positions, ${\bf a}$,
-!   given in the {\tt atoms} block are assumed to be in Cartesian coordinates.
+!   If {\tt molecule} is {\tt .true.}, then the atomic positions given in the
+!   {\tt atoms} block are assumed to be in Cartesian coordinates.
 !
 !   \block{momfix}{
 !   {\tt momfix} & the desired total moment for a FSM calculation &
@@ -1397,10 +1425,20 @@ end program
 !   {\tt rmtall} & muffin-tin radius for all species & real & $-1.0$}
 !   If {\tt rmtall} is positive then all muffin-tin radii are set to this value.
 !
+!   \block{rmtdelta}{
+!   {\tt rmtdelta} & minimum allowed distance between muffin-tin surfaces &
+!    real & $0.05$}
+!
 !   \block{rmtscf}{
 !   {\tt rmtscf} & muffin-tin radius scaling factor & real & $1.0$}
 !   All muffin-tin radii read from the species files are scaled by this factor.
 !
+!   \block{rndavec}{
+!   {\tt rndavec} & lattice vector randomisation amplitude & real & $0.0$}
+!   Setting this to a number larger than zero causes the code add random jitter
+!   to the lattice vectors proportional to this amplitude. This can be used to
+!   break lattice symmetry.
+!
 !   \block{rotavec}{
 !   {\tt axang} & axis-angle representation of lattice vector rotation &
 !    real(4) & $(0.0,0.0,0.0,0.0)$}
@@ -1637,6 +1675,10 @@ end program
 !    to {\tt STRESS.OUT}. \\
 !   450 & Generates a laser pulse in the form of a time-dependent vector
 !    potential ${\bf A}(t)$ and writes it to {\tt AFIELDT.OUT}. \\
+!   455 & Writes the time-dependent power density and total energy density of
+!    ${\bf A}(t)$. \\
+!   456 & Writes the frequency-dependent electric field ${\bf E}(\omega)$
+!    corresponding to ${\bf A}(t)$. \\
 !   460/1/2/3 & Time evolution run using TDDFT under the influence of
 !    ${\bf A}(t)$. Tasks 462 and 463 include nuclear Ehrenfest dynamics. Tasks
 !    461 and 463 restart interrupted calculations. \\
@@ -1926,7 +1968,7 @@ end program
 !    example:
 !    \begin{verbatim}
 !     write(*,*)
-!     write(*,'("Error(readinput): natoms <= 0 : ",I8)') natoms(is)
+!     write(*,'("Error(readinput): natoms < 1 : ",I8)') natoms(is)
 !     write(*,'(" for species ",I4)') is
 !     write(*,*)
 !     stop
