@@ -29,16 +29,15 @@ integer is,ia,ja,ias,jas
 integer nr,nri,nnf,l
 logical fnd
 ! automatic arrays
-logical done(natmmax)
 real(8) vr(nrmtmax)
 nnf=0
 is=isldu(1,idu)
 l=isldu(2,idu)
 nr=nrmt(is)
 nri=nrmti(is)
-done(:)=.false.
 do ia=1,natoms(is)
-  if (done(ia)) cycle
+! perform calculation for only the first equivalent atom
+  if (.not.tfeqat(ia,is)) cycle
   ias=idxas(ia,is)
   call rfmtlm(1,nr,nri,vsmt(:,ias),vr)
   vr(1:nr)=vr(1:nr)*y00
@@ -46,13 +45,11 @@ do ia=1,natoms(is)
   efdu(l,ias)=-0.5d0
   call findband(solsc,l,nrmt(is),rsp(1,is),vr,epsband,demaxbnd,efdu(l,ias),fnd)
   if (.not.fnd) nnf=nnf+1
-  done(ia)=.true.
 ! copy to equivalent atoms
   do ja=1,natoms(is)
-    if ((.not.done(ja)).and.(eqatoms(ia,ja,is))) then
+    if (eqatoms(ia,ja,is).and.(ia /= ja)) then
       jas=idxas(ja,is)
       efdu(l,jas)=efdu(l,ias)
-      done(ja)=.true.
     end if
   end do
 ! end loops over atoms and species
