@@ -13,12 +13,11 @@ complex(8), intent(in) :: kmat(nstsv,nstsv)
 complex(8), intent(in) :: evecsv(nstsv,nstsv),evecsvt(nstsv,nstsv)
 ! local variables
 integer ist
-real(8) wo
-complex(8) z1
+real(8) wo,t1
 ! allocatable arrays
 complex(8), allocatable :: a(:,:),b(:,:)
 ! external functions
-complex(8), external :: zdotc
+real(8), external :: ddot
 allocate(a(nstsv,nstsv),b(nstsv,nstsv))
 ! form the kinetic operator matrix elements in the first-variational basis
 call zgemm('N','C',nstsv,nstsv,nstsv,zone,kmat,nstsv,evecsv,nstsv,zzero,a,nstsv)
@@ -29,9 +28,9 @@ do ist=1,nstsv
   wo=occsv(ist,ik)
   if (abs(wo) < epsocc) cycle
   wo=wo*wkpt(ik)
-  z1=zdotc(nstsv,evecsvt(:,ist),1,a(:,ist),1)
+  t1=ddot(2*nstsv,evecsvt(:,ist),1,a(:,ist),1)
 !$OMP ATOMIC
-  engykn=engykn+wo*dble(z1)
+  engykn=engykn+wo*t1
 end do
 deallocate(a,b)
 end subroutine
