@@ -1,15 +1,19 @@
+
+! Copyright (C) 2002-2007 J. K. Dewhurst, S. Sharma and C. Ambrosch-Draxl.
+! This file is distributed under the terms of the GNU General Public License.
+! See the file COPYING for license details.
+
 subroutine getedata(etype,nparam,ename,pname)
 ! get eos name and number of parameters
 implicit none
 ! arguments
 integer, intent(in) :: etype
 integer, intent(out) :: nparam
-character(256), intent(out) :: ename(2)
-character(256), intent(out) :: pname(*)
+character(256), intent(out) :: ename(2),pname(*)
 select case(etype)
 case(1)
   ename(1)="Universal EOS"
-  ename(2)="Vinet P et al., J. Phys.: Condens. Matter 1, p1941 (1989)"
+  ename(2)="Vinet P. et al., J. Phys.: Condens. Matter 1, p1941 (1989)"
   nparam=4
   pname(1)="V0"
   pname(2)="E0"
@@ -17,7 +21,7 @@ case(1)
   pname(4)="B0'"
 case(2)
   ename(1)="Murnaghan EOS"
-  ename(2)="Murnaghan F D, Am. J. Math. 49, p235 (1937)"
+  ename(2)="Murnaghan F. D., Am. J. Math. 49, p235 (1937)"
   nparam=4
   pname(1)="V0"
   pname(2)="E0"
@@ -25,7 +29,7 @@ case(2)
   pname(4)="B0'"
 case(3)
   ename(1)="Birch-Murnaghan 3rd-order EOS"
-  ename(2)="Birch F, Phys. Rev. 71, p809 (1947)"
+  ename(2)="Birch F., Phys. Rev. 71, p809 (1947)"
   nparam=4
   pname(1)="V0"
   pname(2)="E0"
@@ -33,7 +37,7 @@ case(3)
   pname(4)="B0'"
 case(4)
   ename(1)="Birch-Murnaghan 4th-order EOS"
-  ename(2)="Birch F, Phys. Rev. 71, p809 (1947)"
+  ename(2)="Birch F., Phys. Rev. 71, p809 (1947)"
   nparam=5
   pname(1)="V0"
   pname(2)="E0"
@@ -42,7 +46,7 @@ case(4)
   pname(5)="B0''"
 case(5)
   ename(1)="Natural strain 3rd-order EOS"
-  ename(2)="Poirier J-P and Tarantola A, Phys. Earth Planet Int. 109, p1 (1998)"
+  ename(2)="Poirier J-P. and Tarantola A., Phys. Earth Planet Int. 109, p1 (1998)"
   nparam=4
   pname(1)="V0"
   pname(2)="E0"
@@ -50,7 +54,7 @@ case(5)
   pname(4)="B0'"
 case(6)
   ename(1)="Natural strain 4th-order EOS"
-  ename(2)="Poirier J-P and Tarantola A, Phys. Earth Planet Int. 109, p1 (1998)"
+  ename(2)="Poirier J-P. and Tarantola A., Phys. Earth Planet Int. 109, p1 (1998)"
   nparam=5
   pname(1)="V0"
   pname(2)="E0"
@@ -71,6 +75,5 @@ case default
   write(*,*)
   stop
 end select
-return
 end subroutine
 
