@@ -16,21 +16,23 @@ complex(8), intent(in) :: evecfv(nmatmax,nstfv,nspnfv)
 real(8), intent(out) :: evalsvp(nstsv)
 complex(8), intent(out) :: evecsv(nstsv,nstsv)
 ! local variables
-integer ist,jst,ispn
-integer is,ias,i,j,k
-integer nrc,nrci,nrco
-integer l,lm,nm,npc,npci
-integer igp,ld,nthd
+integer ld,ist,jst,ispn,is,ias
+integer nrc,nrci,nrco,i,j
+integer l,lm,nm,npc,npc2,npci
+integer n1,n12,n2,n22,igp,nthd
 real(8) ts0,ts1
 complex(8) zq
 ! automatic arrays
 complex(8) wfmt2(npcmtmax,nspnfv),wfmt4(npcmtmax)
 complex(8) wfmt31(npcmtmax),wfmt32(npcmtmax),wfmt33(npcmtmax)
-complex(8) wfgp1(ngkmax),wfgp2(ngkmax),wfgp3(ngkmax)
+complex(4) wfmt5(npcmtmax),wfgp1(ngkmax),wfgp2(ngkmax),wfgp3(ngkmax)
+complex(4) wfir1(ngtc,nspnfv),wfir2(ngtc)
 ! allocatable arrays
-complex(8), allocatable :: wfmt1(:,:,:),wfir1(:,:),wfir2(:)
+complex(4), allocatable :: wfmt0(:,:,:),wfgp0(:,:,:)
+complex(8), allocatable :: wfmt1(:,:,:)
 ! external functions
-complex(8), external :: zdotc
+real(4), external :: sdot
+complex(4), external :: cdotc
 if (.not.spinpol) then
   write(*,*)
   write(*,'("Error(eveqnss): spin-unpolarised calculation")')
@@ -42,15 +44,22 @@ ld=lmmaxdm*nspinor
 call holdthd(nstfv,nthd)
 ! zero the second-variational Hamiltonian (stored in the eigenvector array)
 evecsv(:,:)=0.d0
+! set the diagonal elements equal to the first-variational eigenvalues
+do ispn=1,nspinor
+  do ist=1,nstfv
+    i=nstfv*(ispn-1)+ist
+    evecsv(i,i)=evalfv(ist,ispn)
+  end do
+end do
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
-allocate(wfmt1(npcmtmax,nstfv,nspnfv))
+allocate(wfmt0(npcmtmax,nstfv,nspnfv),wfmt1(npcmtmax,nstfv,nspnfv))
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt2,wfmt31,wfmt32,wfmt33,wfmt4) &
+!$OMP PRIVATE(wfmt2,wfmt31,wfmt32,wfmt33,wfmt4,wfmt5) &
 !$OMP PRIVATE(ias,is,nrc,nrci,nrco) &
-!$OMP PRIVATE(npc,npci,zq,ispn) &
-!$OMP PRIVATE(ist,jst,l,nm,lm,i,j,k) &
+!$OMP PRIVATE(npc,npc2,npci,zq,ispn) &
+!$OMP PRIVATE(ist,jst,l,nm,lm,i,j) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
@@ -58,22 +67,25 @@ do ias=1,natmtot
   nrci=nrcmti(is)
   nrco=nrc-nrci
   npc=npcmt(is)
+  npc2=npc*2
   npci=npcmti(is)
 ! de-phasing factor (FC, FB & LN)
   if (ssdph) zq=zqss(ias)
 ! compute the first-variational wavefunctions
   do ispn=1,nspnfv
     if (ssdph.and.(ispn == 2)) zq=conjg(zq)
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
     do ist=1,nstfv
       call wfmtfv(ias,ngp(ispn),apwalm(:,:,:,ias,ispn),evecfv(:,ist,ispn), &
        wfmt1(:,ist,ispn))
 ! de-phase if required
       if (ssdph) wfmt1(1:npc,ist,ispn)=zq*wfmt1(1:npc,ist,ispn)
+! multiply wavefunction by integration weights and store as single-precision
+      call zcfmtwr(nrc,nrci,wr2cmt(:,is),wfmt1(:,ist,ispn),wfmt0(:,ist,ispn))
     end do
 !$OMP END DO
   end do
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
   do jst=1,nstfv
 ! convert wavefunction to spherical coordinates
     do ispn=1,nspnfv
@@ -116,90 +128,97 @@ do ias=1,natmtot
     end if
 ! add to second-variational Hamiltonian matrix
 ! upper diagonal block
-    call zfmtwr(nrc,nrci,wrcmt(:,is),wfmt31)
-    do ist=1,jst
-      evecsv(ist,jst)=evecsv(ist,jst)+zdotc(npc,wfmt1(:,ist,1),1,wfmt31,1)
+    wfmt5(1:npc)=wfmt31(1:npc)
+    do ist=1,jst-1
+      evecsv(ist,jst)=evecsv(ist,jst)+cdotc(npc,wfmt0(:,ist,1),1,wfmt5,1)
     end do
+    evecsv(jst,jst)=evecsv(jst,jst)+sdot(npc2,wfmt0(:,jst,1),1,wfmt5,1)
     j=jst+nstfv
 ! lower diagonal block
-    call zfmtwr(nrc,nrci,wrcmt(:,is),wfmt32)
-    do ist=1,jst
+    wfmt5(1:npc)=wfmt32(1:npc)
+    do ist=1,jst-1
       i=ist+nstfv
-      evecsv(i,j)=evecsv(i,j)+zdotc(npc,wfmt1(:,ist,2),1,wfmt32,1)
+      evecsv(i,j)=evecsv(i,j)+cdotc(npc,wfmt0(:,ist,2),1,wfmt5,1)
     end do
+    evecsv(j,j)=evecsv(j,j)+sdot(npc2,wfmt0(:,jst,2),1,wfmt5,1)
 ! off-diagonal block
-    call zfmtwr(nrc,nrci,wrcmt(:,is),wfmt33)
+    wfmt5(1:npc)=wfmt33(1:npc)
     do ist=1,nstfv
-      evecsv(ist,j)=evecsv(ist,j)+zdotc(npc,wfmt1(:,ist,1),1,wfmt33,1)
+      evecsv(ist,j)=evecsv(ist,j)+cdotc(npc,wfmt0(:,ist,1),1,wfmt5,1)
     end do
   end do
 !$OMP END DO
 ! end loop over atoms
 end do
 !$OMP END PARALLEL
-deallocate(wfmt1)
+deallocate(wfmt0,wfmt1)
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
+allocate(wfgp0(ngkmax,nstfv,nspnfv))
+n1=ngp(1); n12=n1*2
+n2=ngp(2); n22=n2*2
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(wfir1,wfir2,wfgp1,wfgp2,wfgp3) &
-!$OMP PRIVATE(ispn,igp,ist,i,j) &
+!$OMP PRIVATE(ist,jst,ispn,igp,i,j) &
 !$OMP NUM_THREADS(nthd)
-allocate(wfir1(ngtot,nspnfv),wfir2(ngtot))
+! make single-precision copy of wavefunction
+!$OMP DO SCHEDULE(DYNAMIC)
+  do ist=1,nstfv
+    do ispn=1,nspnfv
+      wfgp0(1:ngp(ispn),ist,ispn)=evecfv(1:ngp(ispn),ist,ispn)
+    end do
+  end do
+!$OMP END DO
 ! begin loop over states
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do jst=1,nstfv
   do ispn=1,nspnfv
-    wfir1(:,ispn)=0.d0
+    wfir1(:,ispn)=0.e0
     do igp=1,ngp(ispn)
-      wfir1(igfft(igpig(igp,ispn)),ispn)=evecfv(igp,jst,ispn)
+      wfir1(igfc(igpig(igp,ispn)),ispn)=wfgp0(igp,jst,ispn)
     end do
 ! Fourier transform wavefunction to real-space
-    call zfftifc(3,ngridg,1,wfir1(:,ispn))
+    call cfftifc(3,ngdgc,1,wfir1(:,ispn))
   end do
 ! multiply with magnetic field and transform to G-space
-  wfir2(1:ngtot)=bsir(1:ngtot,3)*wfir1(1:ngtot,1)
-  call zfftifc(3,ngridg,-1,wfir2)
-  do igp=1,ngp(1)
-    wfgp1(igp)=wfir2(igfft(igpig(igp,1)))
+  wfir2(1:ngtc)=bsirc(1:ngtc,3)*wfir1(1:ngtc,1)
+  call cfftifc(3,ngdgc,-1,wfir2)
+  do igp=1,n1
+    wfgp1(igp)=wfir2(igfc(igpig(igp,1)))
   end do
-  wfir2(1:ngtot)=-bsir(1:ngtot,3)*wfir1(1:ngtot,2)
-  call zfftifc(3,ngridg,-1,wfir2)
-  do igp=1,ngp(2)
-    wfgp2(igp)=wfir2(igfft(igpig(igp,2)))
+  wfir2(1:ngtc)=-bsirc(1:ngtc,3)*wfir1(1:ngtc,2)
+  call cfftifc(3,ngdgc,-1,wfir2)
+  do igp=1,n2
+    wfgp2(igp)=wfir2(igfc(igpig(igp,2)))
   end do
-  wfir2(1:ngtot)=cmplx(bsir(1:ngtot,1),-bsir(1:ngtot,2),8)*wfir1(1:ngtot,2)
-  call zfftifc(3,ngridg,-1,wfir2)
-  do igp=1,ngp(1)
-    wfgp3(igp)=wfir2(igfft(igpig(igp,1)))
+  wfir2(1:ngtc)=cmplx(bsirc(1:ngtc,1),-bsirc(1:ngtc,2),8)*wfir1(1:ngtc,2)
+  call cfftifc(3,ngdgc,-1,wfir2)
+  do igp=1,n1
+    wfgp3(igp)=wfir2(igfc(igpig(igp,1)))
   end do
 ! add to second-variational Hamiltonian matrix
 ! upper diagonal block
-  do ist=1,jst
-    evecsv(ist,jst)=evecsv(ist,jst)+zdotc(ngp(1),evecfv(:,ist,1),1,wfgp1,1)
+  do ist=1,jst-1
+    evecsv(ist,jst)=evecsv(ist,jst)+cdotc(n1,wfgp0(:,ist,1),1,wfgp1,1)
   end do
+  evecsv(jst,jst)=evecsv(jst,jst)+sdot(n12,wfgp0(:,jst,1),1,wfgp1,1)
 ! lower diagonal block
   j=jst+nstfv
-  do ist=1,jst
+  do ist=1,jst-1
     i=ist+nstfv
-    evecsv(i,j)=evecsv(i,j)+zdotc(ngp(2),evecfv(:,ist,2),1,wfgp2,1)
+    evecsv(i,j)=evecsv(i,j)+cdotc(n2,wfgp0(:,ist,2),1,wfgp2,1)
   end do
+  evecsv(j,j)=evecsv(j,j)+sdot(n22,wfgp0(:,jst,2),1,wfgp2,1)
 ! off-diagonal block
   do ist=1,nstfv
-    evecsv(ist,j)=evecsv(ist,j)+zdotc(ngp(1),evecfv(:,ist,1),1,wfgp3,1)
+    evecsv(ist,j)=evecsv(ist,j)+cdotc(n1,wfgp0(:,ist,1),1,wfgp3,1)
   end do
 end do
 !$OMP END DO
-deallocate(wfir1,wfir2)
 !$OMP END PARALLEL
+deallocate(wfgp0)
 call freethd(nthd)
-! add the diagonal first-variational part
-do ispn=1,nspinor
-  do ist=1,nstfv
-    i=nstfv*(ispn-1)+ist
-    evecsv(i,i)=evecsv(i,i)+evalfv(ist,ispn)
-  end do
-end do
 ! diagonalise the second-variational Hamiltonian
 call eveqnzh(nstsv,nstsv,evecsv,evalsvp)
 call timesec(ts1)
