@@ -38,8 +38,7 @@ implicit none
 ! arguments
 real(8), intent(in) :: sol
 integer, intent(in) :: l,nr
-real(8), intent(in) :: r(nr),vr(nr)
-real(8), intent(in) :: eps,demax
+real(8), intent(in) :: r(nr),vr(nr),eps,demax
 real(8), intent(inout) :: e
 logical, intent(out) :: fnd
 ! local variables
