@@ -42,7 +42,7 @@ do i=n,1,-1
   j=idx(i)
   ik=(j-1)/nstsv+1
   ist=mod(j-1,nstsv)+1
-  if (evalsv(ist,ik).lt.efermi) then
+  if (evalsv(ist,ik) < efermi) then
     m=i
     e=evalsv(ist,ik)
     exit
@@ -53,7 +53,7 @@ do i=m,1,-1
   j=idx(i)
   ik=(j-1)/nstsv+1
   ist=mod(j-1,nstsv)+1
-  if ((e-evalsv(ist,ik)).gt.eps) exit
+  if ((e-evalsv(ist,ik)) > eps) exit
   e=evalsv(ist,ik)
 end do
 ! valence band width
