@@ -28,8 +28,8 @@ implicit none
 ! local variables
 integer md,sym(3,3),its,i,j
 integer i11,i12,i13,i21,i22,i23,i31,i32,i33
-real(8) s(3,3),g(3,3),sgs(3,3),sc(3,3),scp(3,3)
-real(8) c(3,3),d(3,3),v(3),t1
+real(8) s(3,3),g(3,3),sgs(3,3),sc(3,3)
+real(8) c(3,3),v(3),t1
 ! determine metric tensor
 call r3mtm(avec,avec,g)
 ! loop over all possible symmetry matrices
@@ -73,6 +73,7 @@ do i31=-1,1; do i32=-1,1; do i33=-1,1
   end if
 ! check invariance of time-dependent A-field if required
   if (tafieldt) then
+! symmetry matrix in Cartesian coordinates
     call r3mm(s,ainv,c)
     call r3mm(avec,c,sc)
     do its=1,ntimes
@@ -82,17 +83,6 @@ do i31=-1,1; do i32=-1,1; do i33=-1,1
         +abs(afieldt(3,its)-v(3))
       if (t1 > epslat) goto 10
     end do
-! spin-dependent A-field
-    if (tafspt) then
-! proper part of symmetry matrix
-      scp(:,:)=dble(md)*sc(:,:)
-      do its=1,ntimes
-        call r3mm(sc,afspt(:,:,its),c)
-        call r3mmt(c,scp,d)
-        t1=sum(abs(afspt(:,:,its)-d(:,:)))
-        if (t1 > epslat) goto 10
-      end do
-    end if
   end if
   nsymlat=nsymlat+1
   if (nsymlat > 48) then
