@@ -33,9 +33,9 @@ real(8) t1
 ! real constant 1/sqrt(4*pi)
 real(8), parameter :: c1=0.28209479177387814347d0
 ! external functions
-real(8), external :: wigner3j,factnm,factr
-if ((l1.lt.0).or.(l2.lt.0).or.(l3.lt.0).or.(abs(m1).gt.l1).or.(abs(m2).gt.l2) &
- .or.(abs(m3).gt.l3)) then
+real(8), external :: wigner3j,factn,factr
+if ((l1 < 0).or.(l2 < 0).or.(l3 < 0).or.(abs(m1) > l1).or.(abs(m2) > l2) &
+ .or.(abs(m3) > l3)) then
   write(*,*)
   write(*,'("Error(gaunt): non-physical arguments :")')
   write(*,'("l1 = ",I8," l2 = ",I8," l3 = ",I8)') l1,l2,l3
@@ -43,34 +43,33 @@ if ((l1.lt.0).or.(l2.lt.0).or.(l3.lt.0).or.(abs(m1).gt.l1).or.(abs(m2).gt.l2) &
   write(*,*)
   stop
 end if
-if ((l1.gt.50).or.(l2.gt.50).or.(l3.gt.50)) then
+if ((l1 > 50).or.(l2 > 50).or.(l3 > 50)) then
   write(*,*)
   write(*,'("Error(gaunt): angular momenta out of range : ",3I8)') l1,l2,l3
   write(*,*)
   stop
 end if
-if (m1-m2-m3.ne.0) then
+if (m1-m2-m3 /= 0) then
   gaunt=0.d0
   return
 end if
 j1=l2-l1+l3
 j2=l1-l2+l3
 j3=l1+l2-l3
-if ((j1.lt.0).or.(j2.lt.0).or.(j3.lt.0)) then
+if ((j1 < 0).or.(j2 < 0).or.(j3 < 0)) then
   gaunt=0.d0
   return
 end if
 j=l1+l2+l3
-if (mod(j,2).ne.0) then
+if (mod(j,2) /= 0) then
   gaunt=0.d0
   return
 end if
 jh=j/2
-t1=sqrt(dble((2*l1+1)*(2*l2+1)*(2*l3+1))*factr(j1,j+1)*factnm(j2,1) &
- *factnm(j3,1))
-t1=t1*factr(jh,jh-l1)/(factnm(jh-l2,1)*factnm(jh-l3,1))
+t1=sqrt(dble((2*l1+1)*(2*l2+1)*(2*l3+1))*factr(j1,j+1)*factn(j2)*factn(j3))
+t1=t1*factr(jh,jh-l1)/(factn(jh-l2)*factn(jh-l3))
 gaunt=t1*c1*wigner3j(l1,l2,l3,-m1,m2,m3)
-if (mod(m1+jh,2).ne.0) gaunt=-gaunt
+if (mod(m1+jh,2) /= 0) gaunt=-gaunt
 end function
 !EOC
 
