@@ -26,6 +26,7 @@ use modomp
 ! !REVISION HISTORY:
 !   Created April 2003 (JKD)
 !   Added polarised cores, November 2009 (JKD)
+!   Fixed race condition, February 2025 (JKD)
 !EOP
 !BOC
 implicit none
@@ -33,33 +34,24 @@ implicit none
 integer ist,ispn,idm
 integer is,ia,ja,ias,jas
 integer nr,nri,nrs,nthd
-real(8) v(ndmag),t1
+real(8) v(3),t1
 ! automatic arrays
-logical done(natmtot)
 real(8) vr(nrspmax),br(nrmtmax),fr(nrmtmax),eval(nstspmax)
 ! external functions
 real(8), external :: rfmtint
-done(:)=.false.
 ! loop over species and atoms
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(vr,br,fr,eval) &
-!$OMP PRIVATE(is,ia,ja,jas) &
-!$OMP PRIVATE(nr,nri,nrs,idm) &
-!$OMP PRIVATE(v,t1,ispn,ist) &
+!$OMP PRIVATE(is,ia,nr,nri,nrs,idm) &
+!$OMP PRIVATE(v,t1,ispn,ist,ja,jas) &
 !$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
   ia=idxia(ias)
-! flag all equivalent atoms as done
-!$OMP CRITICAL
-  do ja=1,natoms(is)
-    jas=idxas(ja,is)
-    if ((ia /= ja).and.(eqatoms(ia,ja,is))) done(jas)=.true.
-  end do
-!$OMP END CRITICAL
-  if (done(ias)) cycle
+! perform calculation for only the first equivalent atom
+  if (.not.tfeqat(ia,is)) cycle
   nr=nrmt(is)
   nri=nrmti(is)
   nrs=nrsp(is)
@@ -128,11 +120,10 @@ do ias=1,natmtot
     rhocr(1:nr,ias,ispn)=rhocr(1:nr,ias,ispn)*rlmt(1:nr,-2,is)*y00
 ! end loop over spin channels
   end do
-! flag atom as done and copy to equivalent atoms
-  done(ias)=.true.
+! copy to equivalent atoms
   do ja=1,natoms(is)
-    jas=idxas(ja,is)
-    if (eqatoms(ia,ja,is)) then
+    if (eqatoms(ia,ja,is).and.(ia /= ja)) then
+      jas=idxas(ja,is)
       do ist=1,nstsp(is)
         if (spcore(ist,is)) then
           evalcr(ist,jas)=evalcr(ist,ias)
