@@ -12,13 +12,14 @@ integer ig
 real(8) v1,v2,v3,t1,t2
 complex(8) z1
 v1=atposc(1,iaph,isph); v2=atposc(2,iaph,isph); v3=atposc(3,iaph,isph)
-do ig=1,ngtot
+do ig=1,ngvec
   t1=vgqc(1,ig)*v1+vgqc(2,ig)*v2+vgqc(3,ig)*v3
   t2=ffacgq(ig,isph)*vgqc(ipph,ig)
   z1=t2*cmplx(sin(t1),cos(t1),8)
   dcfunig(ig)=z1
   dcfunir(igfft(ig))=z1
 end do
+dcfunir(igfft(ngvec+1:ngtot))=0.d0
 call zfftifc(3,ngridg,1,dcfunir)
 end subroutine
 
