@@ -36,9 +36,8 @@ do ias=1,natmtot
   end do
   call splined(nr,wcrmt(:,:,is),vr1,dvr1)
   call splined(nr,wcrmt(:,:,is),vr2,dvr2)
-  irc=0
   do ir=1,nr,lradstp
-    irc=irc+1
+    irc=(ir-1)/lradstp+1
     z1=cmplx(dvr1(ir),dvr2(ir),8)
     dsocfr(irc,ias)=(cso/rsp(ir,is))*z1
   end do
