@@ -10,8 +10,8 @@ use modmpi
 implicit none
 ! arguments
 integer, intent(in) :: ik
-real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtot)
-real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
+real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtc)
+real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag)
 complex(8), intent(in) :: kmat(nstsv,nstsv),pmat(nstsv,nstsv,3)
 complex(8), intent(out) :: h(nstsv,nstsv)
 ! local variables
