@@ -32,12 +32,12 @@ integer, intent(in) :: ld
 real(8), intent(out) :: jlgprmt(0:lmax,ld,nspecies)
 ! local variables
 integer is,ig
-real(8) r,t1
+real(8) r,x
 do is=1,nspecies
   r=rmt(is)
   do ig=1,ngp
-    t1=gpc(ig)*r
-    call sbessel(lmax,t1,jlgprmt(:,ig,is))
+    x=gpc(ig)*r
+    call sbessel(lmax,x,jlgprmt(:,ig,is))
   end do
 end do
 end subroutine
