@@ -30,19 +30,22 @@ logical, intent(in) :: tfv,tvclcr
 ! local variables
 integer ik,nthd
 ! allocatable arrays
-real(8), allocatable :: vmt(:,:),vir(:),bmt(:,:,:)
-allocate(vmt(npcmtmax,natmtot),vir(ngtot))
-if (spinpol) allocate(bmt(npcmtmax,natmtot,ndmag))
+real(8), allocatable :: vmt(:,:),vir(:),bmt(:,:,:),bir(:,:)
+allocate(vmt(npcmtmax,natmtot),vir(ngtc))
+if (spinpol) then
+  allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag))
+end if
 ! generate the Kohn-Sham potential and magnetic field in spherical coordinates
 ! and multiply by the radial integration weights; also multiply the interstitial
 ! potential with the characteristic function
-call vblocal(vmt,vir,bmt)
+call vblocal(vmt,vir,bmt,bir)
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 if (mp_mpi) write(*,*)
 ! loop over k-points
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ik=1,nkpt
 ! distribute among MPI processes
@@ -50,12 +53,12 @@ do ik=1,nkpt
 !$OMP CRITICAL(genkmat_)
   write(*,'("Info(genkmat): ",I6," of ",I6," k-points")') ik,nkpt
 !$OMP END CRITICAL(genkmat_)
-  call putkmat(tfv,tvclcr,ik,vmt,vir,bmt,bsir)
+  call putkmat(tfv,tvclcr,ik,vmt,vir,bmt,bir)
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
 deallocate(vmt,vir)
-if (spinpol) deallocate(bmt)
+if (spinpol) deallocate(bmt,bir)
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
 end subroutine
