@@ -12,7 +12,7 @@ integer, intent(in) :: nst
 complex(8), intent(in) :: expqmt(npcmtmax,natmtot)
 integer, intent(in) :: ngpq(nspnfv),igpqig(ngkmax,nspnfv)
 complex(8), intent(in) :: wfmt(npcmtmax,natmtot,nspinor,nst)
-complex(8), intent(in) :: wfir(ngtot,nspinor,nst)
+complex(8), intent(in) :: wfir(ngtc,nspinor,nst)
 complex(8), intent(in) :: wfmtq(npcmtmax,natmtot,nspinor,nst)
 complex(8), intent(in) :: wfgpq(ngkmax,nspinor,nst)
 complex(8), intent(out) :: oq(nst,nst)
@@ -22,20 +22,19 @@ integer is,ias,nrc,nrci
 integer npc,igpq,nthd
 real(8) t1
 ! automatic arrays
-complex(8) wfmt1(npcmtmax),z(ngkmax)
-! allocatable arrays
-complex(8), allocatable :: wfir1(:)
+complex(8) wfmt1(npcmtmax),wfir1(ngtc),z(ngkmax)
 ! external functions
 complex(8), external :: zdotc
 call holdthd(nst,nthd)
 ! zero the matrix elements
-oq(:,:)=0.d0
+oq(1:nst,1:nst)=0.d0
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(wfmt1,ispn,ias,is) &
 !$OMP PRIVATE(nrc,nrci,npc,ist) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do jst=1,nst
   do ispn=1,nspinor
@@ -47,7 +46,7 @@ do jst=1,nst
 ! multiply by local phase factor function exp(iq.r)
       wfmt1(1:npc)=expqmt(1:npc,ias)*wfmt(1:npc,ias,ispn,jst)
 ! apply the radial integral weights
-      call zfcmtwr(nrc,nrci,wrcmt(:,is),wfmt1)
+      call zfcmtwr(nrc,nrci,wr2cmt(:,is),wfmt1)
 ! compute the inner products
       do ist=1,nst
         oq(ist,jst)=oq(ist,jst)+zdotc(npc,wfmtq(:,ias,ispn,ist),1,wfmt1,1)
@@ -60,30 +59,27 @@ end do
 !     interstitial part     !
 !---------------------------!
 t1=sqrt(omega)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(wfir1,z,ispn,jspn) &
 !$OMP PRIVATE(igpq,ist) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
-allocate(wfir1(ngtot))
-!$OMP DO
 do jst=1,nst
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
 ! multiply wavefunction by characteristic function
-    wfir1(:)=wfir(:,ispn,jst)*cfunir(:)
+    wfir1(1:ngtc)=wfir(1:ngtc,ispn,jst)*cfrc(1:ngtc)
 ! Fourier transform to G+p+q-space
-    call zfftifc(3,ngridg,-1,wfir1)
+    call zfftifc(3,ngdgc,-1,wfir1)
     do igpq=1,ngpq(jspn)
-      z(igpq)=wfir1(igfft(igpqig(igpq,jspn)))
+      z(igpq)=wfir1(igfc(igpqig(igpq,jspn)))
     end do
     do ist=1,nst
       oq(ist,jst)=oq(ist,jst)+t1*zdotc(ngpq(jspn),wfgpq(:,ispn,ist),1,z,1)
     end do
   end do
 end do
-!$OMP END DO
-deallocate(wfir1)
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
 end subroutine
 
