@@ -13,7 +13,7 @@ real(8), intent(in) :: dph
 ! local variables
 integer is,ia,na,i
 real(8) vc(3),t1
-if ((p.ne.0).and.(p.ne.1)) then
+if ((p /= 0).and.(p /= 1)) then
   write(*,*)
   write(*,'("Error(genscph): phase (p) should be 0 or 1 : ",I8)') p
   write(*,*)
@@ -27,7 +27,7 @@ do is=1,nspecies
   do ia=1,natoms0(is)
     do i=1,nscph
       na=na+1
-      if (na.gt.maxatoms) then
+      if (na > maxatoms) then
         write(*,*)
         write(*,'("Error(genscph): too many atoms in supercell : ",I8)') na
         write(*,'(" for species ",I4)') is
@@ -37,9 +37,9 @@ do is=1,nspecies
       end if
       vc(:)=vscph(:,i)+atposc0(:,ia,is)
 ! add small periodic displacement
-      if ((isph.eq.is).and.(iaph.eq.ia)) then
+      if ((isph == is).and.(iaph == ia)) then
         t1=dot_product(vqc(:,iqph),vscph(:,i))
-        if (p.eq.0) then
+        if (p == 0) then
           vc(ipph)=vc(ipph)+dph*cos(t1)
         else
           vc(ipph)=vc(ipph)+dph*sin(t1)
