@@ -19,7 +19,8 @@ cso=y00*socscf/(4.d0*solsc**2)
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(vr,dvr,is,nr,nri) &
-!$OMP PRIVATE(irc,ir,rm) &
+!$OMP PRIVATE(ir,irc,rm) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
@@ -28,9 +29,8 @@ do ias=1,natmtot
 ! radial derivative of the spherical part of the Kohn-Sham potential
   call rfmtlm(1,nr,nri,vsmt(:,ias),vr)
   call splined(nr,wcrmt(:,:,is),vr,dvr)
-  irc=0
   do ir=1,nr,lradstp
-    irc=irc+1
+    irc=(ir-1)/lradstp+1
     rm=1.d0-2.d0*cso*vr(ir)
     socfr(irc,ias)=cso*dvr(ir)/(rsp(ir,is)*rm**2)
   end do
