@@ -11,24 +11,20 @@ subroutine genvsig
 use modmain
 ! !DESCRIPTION:
 !   Generates the Fourier transform of the Kohn-Sham effective potential in the
-!   interstitial region. The potential is first multiplied by the characteristic
-!   function which zeros it in the muffin-tins. See routine {\tt gencfun}.
+!   interstitial region.
 !
 ! !REVISION HISTORY:
 !   Created January 2004 (JKD)
 !EOP
 !BOC
 implicit none
-! allocatable arrays
-complex(8), allocatable :: zfft(:)
-allocate(zfft(ngtot))
-! multiply potential by characteristic function in real-space
-zfft(:)=vsir(:)*cfunir(:)
-! Fourier transform to G-space
-call zfftifc(3,ngridg,-1,zfft)
+! automatic arrays
+complex(8) zfft(ngtc)
+! Fourier transform intersitial potential to G-space
+zfft(1:ngtc)=vsirc(1:ngtc)
+call zfftifc(3,ngdgc,-1,zfft)
 ! store in global array
-vsig(1:ngvec)=zfft(igfft(1:ngvec))
-deallocate(zfft)
+vsig(1:ngvc)=zfft(igfc(1:ngvc))
 end subroutine
 !EOC
 
