@@ -25,7 +25,7 @@ end if
 t1=pi*t0
 nwgw=2*nint(wmaxgw/t1)
 nwgw=max(nwgw,2)
-call nfftifc(npfftw,nwgw)
+call nfftifc(npfftw,1,nwgw)
 ! determine integer ranges for grid
 intwgw(1)=nwgw/2-nwgw+1
 intwgw(2)=nwgw/2
