@@ -20,7 +20,7 @@ read(320,rec=ik) vkl_,nstsv_,evaluvp
 close(320)
 !$OMP END CRITICAL(u320)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(getevaluv): differing vectors for k-point ",I8)') ik
   write(*,'(" current    : ",3G18.10)') vkl(:,ik)
@@ -28,7 +28,7 @@ if (t1.gt.epslat) then
   write(*,*)
   stop
 end if
-if (nstsv.ne.nstsv_) then
+if (nstsv /= nstsv_) then
   write(*,*)
   write(*,'("Error(getevaluv): differing nstsv for k-point ",I8)') ik
   write(*,'(" current    : ",I8)') nstsv
