@@ -113,7 +113,7 @@ allocate(evecfv_(nmatmax,nstfv))
 lspl=lsplsymc(isym)
 ! the inverse of the spatial symmetry rotates k into p
 ilspl=isymlat(lspl)
-si(:,:)=dble(symlat(:,:,ilspl))
+si(1:3,1:3)=dble(symlat(1:3,1:3,ilspl))
 !-----------------------------------------------!
 !     translate and rotate APW coefficients     !
 !-----------------------------------------------!
@@ -131,9 +131,9 @@ do jspn=1,nspnfv
     v(:)=vtcsymc(:,isym)
     do igk=1,ngk(jspn,ik)
       ig=igkig(igk,jspn,ik)
-      t1=-(vgc(1,ig)*v(1)+vgc(2,ig)*v(2)+vgc(3,ig)*v(3))
-      z1=cmplx(cos(t1),sin(t1),8)
-      evecfv_(igk,:)=z1*evecfv(igk,:,jspn)
+      t1=vgc(1,ig)*v(1)+vgc(2,ig)*v(2)+vgc(3,ig)*v(3)
+      z1=cmplx(cos(t1),-sin(t1),8)
+      evecfv_(igk,1:nstfv)=z1*evecfv(igk,1:nstfv,jspn)
     end do
   end if
 ! apply spatial rotation operation (passive transformation)
@@ -147,7 +147,7 @@ do jspn=1,nspnfv
         +abs(v(2)-vgpl(2,igp,jspn)) &
         +abs(v(3)-vgpl(3,igp,jspn))
       if (t1 < epslat) then
-        evecfv(igp,:,jspn)=evecfv_(igk,:)
+        evecfv(igp,1:nstfv,jspn)=evecfv_(igk,1:nstfv)
         done(igp)=.true.
         exit
       end if
@@ -170,7 +170,7 @@ if (nlotot > 0) then
   do jspn=1,nspnfv
 ! make a copy of the local-orbital coefficients
     do i=ngk(jspn,ik)+1,nmat(jspn,ik)
-      evecfv_(i,:)=evecfv(i,:,jspn)
+      evecfv_(i,1:nstfv)=evecfv(i,1:nstfv,jspn)
     end do
     do is=1,nspecies
       do ia=1,natoms(is)
@@ -181,7 +181,7 @@ if (nlotot > 0) then
 ! phase factor from translation
         t1=-twopi*dot_product(vkl(1:3,ik),atposl(1:3,ja,is))
         z1=cmplx(cos(t1),sin(t1),8)
-        t1=twopi*dot_product(v(:),atposl(:,ia,is))
+        t1=twopi*dot_product(v(1:3),atposl(1:3,ia,is))
         z1=z1*cmplx(cos(t1),sin(t1),8)
 ! rotate local-orbitals (active transformation)
         do ilo=1,nlorb(is)
@@ -191,7 +191,7 @@ if (nlotot > 0) then
           j=ngk(jspn,ik)+idxlo(lm,ilo,jas)
           call rotzflm(symlatc(:,:,lspl),l,l,lolmmax,nstfv,nmatmax, &
            evecfv_(j,1),evecfv(i,1,jspn))
-          evecfv(i:i+2*l,:,jspn)=z1*evecfv(i:i+2*l,:,jspn)
+          evecfv(i:i+2*l,1:nstfv,jspn)=z1*evecfv(i:i+2*l,1:nstfv,jspn)
         end do
       end do
     end do
