@@ -14,7 +14,7 @@ complex(8), intent(out) :: u(nstsv,nstsv),v(nstsv,nstsv)
 integer isym,ik
 integer recl,nstsv_
 real(8) vkl_(3),t1
-if (ikp.gt.0) then
+if (ikp > 0) then
   ik=ikp
 else
 ! find the equivalent k-point number and symmetry which rotates vkl to vpl
@@ -28,7 +28,7 @@ read(322,rec=ik) vkl_,nstsv_,u,v
 close(322)
 !$OMP END CRITICAL(u322)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
-if (t1.gt.epslat) then
+if (t1 > epslat) then
   write(*,*)
   write(*,'("Error(getevecuv): differing vectors for k-point ",I8)') ik
   write(*,'(" current    : ",3G18.10)') vkl(:,ik)
@@ -36,7 +36,7 @@ if (t1.gt.epslat) then
   write(*,*)
   stop
 end if
-if (nstsv.ne.nstsv_) then
+if (nstsv /= nstsv_) then
   write(*,*)
   write(*,'("Error(getevecuv): differing nstsv for k-point ",I8)') ik
   write(*,'(" current    : ",I8)') nstsv
