@@ -25,12 +25,13 @@ complex(8), external :: gwtails
 allocate(se(nstsv,nstsv,0:nwfm))
 call getgwsefm(ik,se)
 ! zero the density matrix
-d(:,:)=0.d0
+d(1:nstsv,1:nstsv)=0.d0
 ! loop over fermionic Matsubara frequencies
 call holdthd(nwfm+1,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP PRIVATE(gs,g,ist,e,z1,i) &
+!$OMP PRIVATE(gs,g,ist,jst,e,z1,i) &
 !$OMP REDUCTION(+:d) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do iw=0,nwfm
 ! compute the diagonal matrix G_s
@@ -41,7 +42,7 @@ do iw=0,nwfm
 ! compute 1 - G_s Σ
   do ist=1,nstsv
     z1=-gs(ist)
-    g(ist,:)=z1*se(ist,:,iw)
+    g(ist,1:nstsv)=z1*se(ist,1:nstsv,iw)
     g(ist,ist)=g(ist,ist)+1.d0
   end do
 ! invert this matrix
@@ -49,17 +50,17 @@ do iw=0,nwfm
 ! compute G = (1 - G_s Σ)⁻¹ G_s
   do jst=1,nstsv
     z1=gs(jst)
-    g(:,jst)=g(:,jst)*z1
+    g(1:nstsv,jst)=g(1:nstsv,jst)*z1
   end do
 ! add to the density matrix
-  d(:,:)=d(:,:)+g(:,:)
+  d(1:nstsv,1:nstsv)=d(1:nstsv,1:nstsv)+g(1:nstsv,1:nstsv)
 ! store the Green's function at the end point frequencies
   i=0
   if (iw == 0) i=1
   if (iw == 1) i=2
   if (iw == nwfm-1) i=3
   if (iw == nwfm) i=4
-  if (i /= 0) ge(i,:,:)=g(:,:)
+  if (i /= 0) ge(i,1:nstsv,1:nstsv)=g(1:nstsv,1:nstsv)
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
@@ -71,7 +72,7 @@ do jst=1,nstsv
 end do
 ! multiply by 1/β
 t1=kboltz*tempk
-d(:,:)=t1*d(:,:)
+d(1:nstsv,1:nstsv)=t1*d(1:nstsv,1:nstsv)
 deallocate(se)
 ! make density matrix Hermitian
 do ist=1,nstsv
@@ -84,7 +85,7 @@ do ist=1,nstsv
 end do
 ! diagonalise the density matrix for the natural orbitals and occupation numbers
 call eveqnzh(nstsv,nstsv,d,occsv(:,ik))
-occsv(:,ik)=occsv(:,ik)*occmax
+occsv(1:nstsv,ik)=occsv(1:nstsv,ik)*occmax
 ! get the second-variational eigenvectors from file
 call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! apply unitary transformation to the third-variational states so that they
