@@ -11,6 +11,7 @@ implicit none
 ! local variables
 integer ik,lp,nthd
 real(8) etp,de
+character(64) str
 ! allocatable arrays
 real(8), allocatable :: vmt(:,:),vir(:)
 real(8), allocatable :: bmt(:,:,:),bir(:,:)
@@ -38,9 +39,9 @@ call occupy
 ! generate the kinetic matrix elements in the first-variational basis
 call genkmat(.true.,.true.)
 ! allocate local arrays
-allocate(vmt(npcmtmax,natmtot),vir(ngtot))
+allocate(vmt(npcmtmax,natmtot),vir(ngtc))
 if (hybrid.and.spinpol) then
-  allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag))
+  allocate(bmt(npcmtmax,natmtot,ndmag),bir(ngtc,ndmag))
 end if
 ! only the MPI master process should write files
 if (mp_mpi) then
@@ -66,17 +67,12 @@ tlast=.false.
 etp=0.d0
 ! begin the self-consistent loop
 if (mp_mpi) then
-  write(60,*)
-  write(60,'("+------------------------------+")')
-  write(60,'("| Self-consistent loop started |")')
-  write(60,'("+------------------------------+")')
+  call writebox(60,"Self-consistent loop started")
 end if
 do iscl=1,maxscl
   if (mp_mpi) then
-    write(60,*)
-    write(60,'("+--------------------+")')
-    write(60,'("| Loop number : ",I4," |")') iscl
-    write(60,'("+--------------------+")')
+    write(str,'("Loop number : ",I0)') iscl
+    call writebox(60,trim(str))
     flush(60)
     write(*,'("Info(hartfock): self-consistent loop number : ",I4)') iscl
   end if
@@ -98,7 +94,7 @@ do iscl=1,maxscl
 !$OMP PRIVATE(evecsv) &
 !$OMP NUM_THREADS(nthd)
   allocate(evecsv(nstsv,nstsv))
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
   do ik=1,nkpt
 ! distribute among MPI processes
     if (mod(ik-1,np_mpi) /= lp_mpi) cycle
@@ -198,10 +194,7 @@ do iscl=1,maxscl
 end do
 10 continue
 if (mp_mpi) then
-  write(60,*)
-  write(60,'("+------------------------------+")')
-  write(60,'("| Self-consistent loop stopped |")')
-  write(60,'("+------------------------------+")')
+  call writebox(60,"Self-consistent loop stopped")
   if (maxscl > 1) then
     call writestate
     write(60,*)
@@ -217,10 +210,6 @@ if (tforce) then
   if (mp_mpi) call writeforces(60)
 end if
 if (mp_mpi) then
-  write(60,*)
-  write(60,'("+----------------------------+")')
-  write(60,'("| Elk version ",I1.1,".",I1.1,".",I2.2," stopped |")') version
-  write(60,'("+----------------------------+")')
 ! close the HF_INFO.OUT file
   close(60)
 ! close the TOTENERGY.OUT file
