@@ -15,8 +15,8 @@ integer, intent(in) :: ld
 complex(8), intent(inout) :: hq(ld,*)
 ! local variables
 integer io,ilo
-integer l1,l2,l3
-integer lm1,lm2,lm3
+integer l0,l1,l2,l3
+integer lm1,lm3,lma,lmb
 integer i0,j0,i,j
 complex(8) z1
 do ilo=1,nlorb(is)
@@ -26,15 +26,13 @@ do ilo=1,nlorb(is)
     i0=ngpq+i
     j0=ngp+i
     do l3=0,lmaxapw
+      if (mod(l1+l3,2) == 0) then; l0=0; else; l0=1; end if
       do lm3=l3**2+1,(l3+1)**2
         do io=1,apword(l3,is)
           z1=0.d0
-          do l2=0,lmaxo
-            if (mod(l1+l2+l3,2) == 0) then
-              do lm2=l2**2+1,(l2+1)**2
-                z1=z1+gntyry(lm2,lm3,lm1)*hloa(lm2,io,l3,ilo,ias)
-              end do
-            end if
+          do l2=l0,lmaxo,2
+            lma=l2**2+1; lmb=lma+2*l2
+            z1=z1+sum(gntyry(lma:lmb,lm3,lm1)*hloa(lma:lmb,io,l3,ilo,ias))
           end do
           if (abs(dble(z1))+abs(aimag(z1)) > 1.d-14) then
             do i=1,ngpq
