@@ -57,9 +57,13 @@ do ias=1,natmtot
       do l3=0,lmaxapw
         do jo=1,apword(l3,is)
           if (l1 == l3) then
-            sm=sum(apwfr(1:nr,1,io,l1,ias)*apwfr(1:nr,2,jo,l3,ias) &
-             *wr2mt(1:nr,is))
-            haa(1,jo,l3,io,l1,ias)=sm*y00i
+            sm=sum((apwfr(1:nr,1,io,l1,ias)*apwfr(1:nr,2,jo,l1,ias) &
+                   +apwfr(1:nr,2,io,l1,ias)*apwfr(1:nr,1,jo,l1,ias)) &
+                   *wr2mt(1:nr,is))
+! add kinetic surface term
+            sm=sm+apwfr(nr,1,io,l1,ias)*apwdfr(jo,l1,ias) &
+                 +apwdfr(io,l1,ias)*apwfr(nr,1,jo,l1,ias)
+            haa(1,jo,l1,io,l1,ias)=sm*y00i/2.d0
           else
             haa(1,jo,l3,io,l1,ias)=0.d0
           end if
@@ -98,32 +102,32 @@ do ias=1,natmtot
   do ilo=1,nlorb(is)
     l1=lorbl(ilo,is)
     do l3=0,lmaxapw
-      do io=1,apword(l3,is)
+      do jo=1,apword(l3,is)
         if (l1 == l3) then
-          sm=sum(lofr(1:nr,1,ilo,ias)*apwfr(1:nr,2,io,l3,ias)*wr2mt(1:nr,is))
-          hloa(1,io,l3,ilo,ias)=sm*y00i
+          sm=sum(lofr(1:nr,1,ilo,ias)*apwfr(1:nr,2,jo,l1,ias)*wr2mt(1:nr,is))
+          hloa(1,jo,l1,ilo,ias)=sm*y00i
         else
-          hloa(1,io,l3,ilo,ias)=0.d0
+          hloa(1,jo,l3,ilo,ias)=0.d0
         end if
         do l2=1,lmaxi
           do lm2=l2**2+1,(l2+1)**2
             i1=lmmaxi*(nri-1)+lm2
-            sm=sum(lofr(1:nri,1,ilo,ias)*apwfr(1:nri,1,io,l3,ias) &
+            sm=sum(lofr(1:nri,1,ilo,ias)*apwfr(1:nri,1,jo,l3,ias) &
              *wr2mt(1:nri,is)*vsmt(lm2:i1:lmmaxi,ias))
             i0=i1+lmmaxi
             i1=lmmaxo*(nr-iro)+i0
-            sm=sm+sum(lofr(iro:nr,1,ilo,ias)*apwfr(iro:nr,1,io,l3,ias) &
+            sm=sm+sum(lofr(iro:nr,1,ilo,ias)*apwfr(iro:nr,1,jo,l3,ias) &
              *wr2mt(iro:nr,is)*vsmt(i0:i1:lmmaxo,ias))
-            hloa(lm2,io,l3,ilo,ias)=sm
+            hloa(lm2,jo,l3,ilo,ias)=sm
           end do
         end do
         do l2=lmaxi+1,lmaxo
           do lm2=l2**2+1,(l2+1)**2
             i0=lmmaxi*nri+lm2
             i1=lmmaxo*(nr-iro)+i0
-            sm=sum(lofr(iro:nr,1,ilo,ias)*apwfr(iro:nr,1,io,l3,ias) &
+            sm=sum(lofr(iro:nr,1,ilo,ias)*apwfr(iro:nr,1,jo,l3,ias) &
              *wr2mt(iro:nr,is)*vsmt(i0:i1:lmmaxo,ias))
-            hloa(lm2,io,l3,ilo,ias)=sm
+            hloa(lm2,jo,l3,ilo,ias)=sm
           end do
         end do
       end do
