@@ -15,7 +15,7 @@ real(8) t1
 ! enforce the von Weizsacker lower bound
 do i=1,n
   t1=(1.d0/8.d0)*grho2(i)/rho(i)
-  if (tau(i).lt.t1) tau(i)=t1
+  if (tau(i) < t1) tau(i)=t1
 end do
 end subroutine
 
