@@ -10,8 +10,6 @@ module modmain
 !----------------------------!
 ! lattice vectors stored column-wise
 real(8) avec(3,3),avec0(3,3),davec(3,3)
-! magnitude of random displacements added to lattice vectors
-real(8) rndavec
 ! inverse of lattice vector matrix
 real(8) ainv(3,3)
 ! reciprocal lattice vectors
@@ -340,8 +338,7 @@ integer, parameter :: maxsymcrys=192
 ! number of crystal symmetries
 integer nsymcrys
 ! crystal symmetry translation vector in lattice and Cartesian coordinates
-real(8) vtlsymc(3,maxsymcrys)
-real(8) vtcsymc(3,maxsymcrys)
+real(8) vtlsymc(3,maxsymcrys),vtcsymc(3,maxsymcrys)
 ! tv0symc is .true. if the translation vector is zero
 logical tv0symc(maxsymcrys)
 ! spatial rotation element in lattice point group for each crystal symmetry
@@ -352,6 +349,8 @@ integer lspnsymc(maxsymcrys)
 integer, allocatable :: ieqatom(:,:,:)
 ! eqatoms(ia,ja,is) is .true. if atoms ia and ja are equivalent
 logical, allocatable :: eqatoms(:,:,:)
+! tfeqat is .true. if this is the first atom in a subset of equivalent atoms
+logical, allocatable :: tfeqat(:,:)
 ! number of site symmetries
 integer, allocatable :: nsymsite(:)
 ! site symmetry spatial rotation element in lattice point group
@@ -404,7 +403,7 @@ real(8), allocatable :: vgc(:,:)
 real(8), allocatable :: gc(:)
 ! Coulomb Green's function in G-space = 4π / G²
 real(8), allocatable :: gclg(:)
-! spherical Bessel functions j_l(|G|R_mt)
+! spherical Bessel functions jₗ(|G|Rₘₜ)
 real(8), allocatable :: jlgrmt(:,:,:)
 ! spherical harmonics of the G-vectors
 complex(8), allocatable :: ylmg(:,:)
@@ -587,7 +586,7 @@ real(8) dncgga
 integer ktype(3)
 ! kinetic energy density functional description
 character(264) kdescr
-! kinetic energy density density gradient requirement (see xcgrad)
+! kinetic energy density gradient requirement (see xcgrad)
 integer kgrad
 ! muffin-tin and interstitial charge density
 real(8), allocatable :: rhomt(:,:),rhoir(:)
@@ -637,9 +636,6 @@ real(8), allocatable :: bsir(:,:)
 real(8), pointer, contiguous :: bsirc(:,:)
 ! G-space interstitial Kohn-Sham effective potential
 complex(8), allocatable :: vsig(:)
-! trimvg is .true. if the components of the effective potential are to be set to
-! zero for |G| > 4 gkmax before the characteristic function is applied
-logical trimvg,trimvg0
 ! nosource is .true. if the field is to be made source-free
 logical nosource
 ! tssxc is .true. if scaled spin exchange-correlation is to be used
@@ -666,6 +662,9 @@ real(8) tempk
 integer mixtype
 ! mixing type description
 character(64) mixdescr
+! if mixsave is .true. then the mixer work array is saved after each self-
+! consistent loop and will be read in at the beginning of a restart
+logical mixsave
 ! adaptive mixing parameters (formerly beta0 and betamax)
 real(8) amixpm(2)
 ! subspace dimension for Broyden mixing
@@ -718,18 +717,18 @@ real(8) jtot(3),jtotm
 !-----------------------------------------!
 !     APW and local-orbital variables     !
 !-----------------------------------------!
-! energy step used for numerical calculation of energy derivatives
-real(8) deapwlo
 ! maximum allowable APW order
-integer, parameter :: maxapword=4
+integer, parameter :: maxapword=3
+! polynomial order used for APW radial derivatives
+integer, parameter :: npapw=8
 ! APW order
 integer apword(0:maxlapw,maxspecies)
 ! maximum of apword over all angular momenta and species
 integer apwordmax
 ! total number of APW coefficients (l, m and order) for each species
 integer lmoapw(maxspecies)
-! polynomial order used for APW radial derivatives
-integer npapw
+! energy step size used for APW numerical derivatives
+real(8) deapw
 ! APW initial linearisation energies
 real(8) apwe0(maxapword,0:maxlapw,maxspecies)
 ! APW linearisation energies
@@ -745,7 +744,9 @@ real(8), allocatable :: apwdfr(:,:,:)
 ! maximum number of local-orbitals
 integer, parameter :: maxlorb=200
 ! maximum allowable local-orbital order
-integer, parameter :: maxlorbord=5
+integer, parameter :: maxlorbord=4
+! polynomial order used for local-orbital radial derivatives
+integer, parameter :: nplorb=8
 ! number of local-orbitals
 integer nlorb(maxspecies)
 ! maximum nlorb over all species
@@ -756,14 +757,14 @@ integer nlotot
 integer lorbord(maxlorb,maxspecies)
 ! maximum lorbord over all species
 integer lorbordmax
-! polynomial order used for local-orbital radial derivatives
-integer nplorb
 ! local-orbital angular momentum
 integer lorbl(maxlorb,maxspecies)
 ! maximum lorbl over all species
 integer lolmax
 ! (lolmax+1)^2
 integer lolmmax
+! energy step size used for local-orbital numerical derivatives
+real(8) delorb
 ! local-orbital initial energies
 real(8) lorbe0(maxlorbord,maxlorb,maxspecies)
 ! local-orbital energies
@@ -981,6 +982,10 @@ real(8) stress(9)
 real(8) stressp(9)
 ! stress tensor component magnitude maximum
 real(8) stressmax
+! reference lattice vectors for generating the G-vectors and derived quantities
+real(8) avecref(3,3)
+! tavref is .true. if avecref is non-zero
+logical tavref
 ! lattice vector optimisation type
 !  0 : no optimisation
 !  1 : unconstrained optimisation
@@ -1094,11 +1099,9 @@ integer maxitoep
 ! OEP initial and subsequent step sizes
 real(8) tau0oep,tauoep
 ! exchange potential and magnetic field
-real(8), allocatable :: vxmt(:,:),vxir(:)
-real(8), allocatable :: bxmt(:,:,:),bxir(:,:)
+real(8), allocatable :: vxmt(:,:),vxir(:),bxmt(:,:,:),bxir(:,:)
 ! OEP residual functions
-real(8), allocatable :: dvxmt(:,:),dvxir(:)
-real(8), allocatable :: dbxmt(:,:,:),dbxir(:,:)
+real(8), allocatable :: dvxmt(:,:),dvxir(:),dbxmt(:,:,:),dbxir(:,:)
 ! magnitude of the OEP residual
 real(8) resoep
 ! hybrid is .true. if a hybrid functional is to be used
@@ -1196,7 +1199,7 @@ complex(8), parameter :: zi=(0.d0,1.d0),zmi=(0.d0,-1.d0)
 !       ⎝1  0⎠         ⎝i  0⎠         ⎝0 -1⎠
 ! Planck constant in SI units (exact, CODATA 2018)
 real(8), parameter :: h_si=6.62607015d-34
-! reduced Planck constant in SI units
+! reduced Planck constant ℏ in SI units
 real(8), parameter :: hbar_si=h_si/twopi
 ! speed of light in SI units (exact, CODATA 2018)
 real(8), parameter :: sol_si=299792458d0
@@ -1239,7 +1242,7 @@ real(8), parameter :: amu=amu_si/em_si
 !     miscellaneous variables     !
 !---------------------------------!
 ! code version
-integer, parameter :: version(3)=[10,2,4]
+integer, parameter :: version(3)=[10,4,5]
 ! maximum number of tasks
 integer, parameter :: maxtasks=40
 ! number of tasks
