@@ -88,7 +88,7 @@ complex(8), allocatable :: gvnsmt(:,:,:)
 logical tdrho1d,tdrho2d,tdrho3d
 logical tdmag1d,tdmag2d,tdmag3d
 logical tdjr1d,tdjr2d,tdjr3d
-logical tddos,tdlsj,tdjtk
+logical tddos,tdlsj,tdjtk,tdxrmk
 ! magnitude of complex numbers added to initial eigenvectors
 real(8) rndevt0
 ! number of time steps between force calculations
