@@ -13,8 +13,6 @@ real(8), external :: radnucl
 do is=1,nspecies
 ! approximate nuclear radius
   rnucl(is)=radnucl(spzn(is))
-! nuclear volume
-  volnucl(is)=(4.d0/3.d0)*pi*rnucl(is)**3
 ! number of radial mesh points to nuclear radius
   nrnucl(is)=1
   do ir=1,nrmt(is)
@@ -23,6 +21,9 @@ do is=1,nspecies
       exit
     end if
   end do
+! nuclear volume determined from integrating to nuclear radius; this is to
+! ensure integrals over the nuclear volume are correctly normalised
+  volnucl(is)=fourpi*sum(wr2mt(1:nrnucl(is),is))
 end do
 end subroutine
 
