@@ -25,6 +25,12 @@ do l=0,lmaxapw
     end do
   end do
 end do
-call zmctmu(tor,lmoapw(is),ngp,a,a,ld,o)
+if (tor) then
+! matrix O is real
+  call rzmmaau(lmoapw(is),ngp,a,ld,o)
+else
+! matrix O is complex
+  call zmmaau(lmoapw(is),ngp,a,ld,o)
+end if
 end subroutine
 
