@@ -26,6 +26,6 @@ do l=0,lmaxapw
     end do
   end do
 end do
-call zmctm(lmoapw(is),ngpq,ngp,a,b,ld,oq)
+call zmmab(lmoapw(is),ngpq,ngp,a,b,ld,oq)
 end subroutine
 
