@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: pade
 ! !INTERFACE:
-subroutine pade(ni,zi,ui,no,zo,uo)
+pure subroutine pade(ni,zi,ui,no,zo,uo)
 ! !INPUT/OUTPUT PARAMETERS:
 !   ni : number of input points (in,integer)
 !   zi : input points (in,complex(ni))
@@ -27,47 +27,43 @@ subroutine pade(ni,zi,ui,no,zo,uo)
 implicit none
 ! arguments
 integer, intent(in) :: ni
-complex(8), intent(in) :: zi(ni)
-complex(8), intent(in) :: ui(ni)
+complex(8), intent(in) :: zi(ni),ui(ni)
 integer, intent(in) :: no
 complex(8), intent(in) :: zo(no)
 complex(8), intent(out) :: uo(no)
 ! local variables
-integer i,j
+integer i,i0,i1,j
 real(8) t1
 complex(8) a0,a1,b0,b1,z1,z2
-! allocatable arrays
-complex(8), allocatable :: g(:,:)
-if ((ni <= 0).or.(no <= 0)) then
-  write(*,*)
-  write(*,'("Error(pade): invalid number of input or output points : ",2I8)') &
-   ni,no
-  write(*,*)
-  stop
-end if
-allocate(g(ni,ni))
+! automatic arrays
+complex(8) g(0:1,ni),gd(ni)
 ! define the g functions using Eq. (A2)
-g(1,:)=ui(:)
+g(0,1:ni)=ui(1:ni)
+gd(1)=ui(1)
 do i=2,ni
+  i0=mod(i-2,2)
+  i1=mod(i-1,2)
   do j=i,ni
-    z1=(zi(j)-zi(i-1))*g(i-1,j)
+    z1=(zi(j)-zi(i-1))*g(i0,j)
     t1=abs(dble(z1))+abs(aimag(z1))
     if (t1 > 1.d-14) then
-      g(i,j)=(g(i-1,i-1)-g(i-1,j))/z1
+      g(i1,j)=(g(i0,i-1)-g(i0,j))/z1
     else
-      g(i,j)=0.d0
+      g(i1,j)=0.d0
     end if
   end do
+! store diagonal elements
+  gd(i)=g(i1,i)
 end do
 ! loop over output points
 do i=1,no
 ! use recursive algorithm in Eq. (A3) to evaluate function
   a0=0.d0
-  a1=g(1,1)
+  a1=gd(1)
   b0=1.d0
   b1=1.d0
   do j=2,ni
-    z1=(zo(i)-zi(j-1))*g(j,j)
+    z1=(zo(i)-zi(j-1))*gd(j)
     z2=a1+z1*a0
     a0=a1
     a1=z2
@@ -97,7 +93,6 @@ do i=1,no
     uo(i)=0.d0
   end if
 end do
-deallocate(g)
 end subroutine
 !EOC
 
