@@ -11,35 +11,26 @@ implicit none
 integer iq,i,iv
 real(8) wmin,wmax,t1
 ! allocatable arrays
-complex(8), allocatable :: dynq(:,:,:),dynr(:,:,:)
-complex(8), allocatable :: dynp(:,:),ev(:,:)
+real(8), allocatable :: wq(:,:)
+complex(8), allocatable :: dq(:,:),ev(:,:)
 ! initialise universal variables
 call init0
 call init2
+call initph
 ! allocate local arrays
-allocate(dynq(nbph,nbph,nqpt))
-allocate(dynr(nbph,nbph,nqptnr))
-allocate(dynp(nbph,nbph))
-allocate(ev(nbph,nbph))
-! read in the dynamical matrices
-call readdyn(dynq)
-! apply the acoustic sum rule
-call sumrule(dynq)
-! Fourier transform the dynamical matrices to real-space
-call dynqtor(dynq,dynr)
+allocate(wq(nbph,npp1d),dq(nbph,nbph),ev(nbph,nbph))
 ! generate a set of q-point vectors along a path in the Brillouin zone
 call plotpt1d(bvec,nvp1d,npp1d,vvlp1d,vplp1d,dvp1d,dpp1d)
-wmin=0.d0
-wmax=0.d0
 ! compute the phonon frequencies along the path
 do iq=ip01d,npp1d
 ! compute the dynamical matrix at this particular q-point
-  call dynrtoq(vplp1d(:,iq),dynr,dynp)
+  call dynrtoq(vplp1d(:,iq),dynr,dq)
 ! find the phonon frequencies and eigenvectors
-  call dynev(dynp,wphq(:,iq),ev)
-  wmin=min(wmin,wphq(1,iq))
-  wmax=max(wmax,wphq(nbph,iq))
+  call dynev(dq,wq(:,iq),ev)
 end do
+! find the minimum and maximum phonon frequencies
+wmin=minval(wq(1,:))
+wmax=maxval(wq(nbph,:))
 t1=(wmax-wmin)*0.5d0
 wmin=wmin-t1
 wmax=wmax+t1
@@ -55,7 +46,7 @@ close(50)
 open(50,file='PHDISP.OUT',form='FORMATTED')
 do i=1,nbph
   do iq=ip01d,npp1d
-    write(50,'(2G18.10)') dpp1d(iq),wphq(i,iq)
+    write(50,'(2G18.10)') dpp1d(iq),wq(i,iq)
   end do
   write(50,*)
 end do
@@ -64,6 +55,6 @@ write(*,*)
 write(*,'("Info(phdisp):")')
 write(*,'(" phonon dispersion written to PHDISP.OUT")')
 write(*,'(" vertex location lines written to PHDLINES.OUT")')
-deallocate(dynq,dynr,dynp,ev)
+deallocate(dq,ev)
 end subroutine
 
