@@ -15,9 +15,8 @@ integer jk,nst,ist
 real(8) vkql(3)
 complex(8) z1
 ! automatic arrays
-integer idx(nstsv),ngp(nspnfv)
+integer idx(nstsv),ngp(nspnfv),igpig(ngkmax,nspnfv)
 ! allocatable arrays
-integer, allocatable :: igpig(:,:)
 complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:)
 complex(8), allocatable :: wfmtq(:,:,:,:),wfgkq(:,:,:)
 complex(8), allocatable :: oq(:,:)
@@ -26,7 +25,7 @@ complex(8), external :: zmdet
 ! equivalent reduced k-point
 jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
 ! find the adjacent k-point in lattice coordinates
-vkql(:)=vkl(:,ik)
+vkql(1:3)=vkl(1:3,ik)
 vkql(l)=vkql(l)+1.d0/dble(ngridk(l))
 ! count and index the occupied states
 nst=0
@@ -35,14 +34,13 @@ do ist=1,nstsv
   nst=nst+1
   idx(nst)=ist
 end do
-allocate(igpig(ngkmax,nspnfv))
 ! generate the wavefunctions for occupied states at k
-allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfir(ngtot,nspinor,nst))
-call genwfsvp(.false.,.false.,nst,idx,ngridg,igfft,vkl(:,ik),ngp,igpig,wfmt, &
- ngtot,wfir)
+allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfir(ngtc,nspinor,nst))
+call genwfsvp(.false.,.false.,nst,idx,ngdgc,igfc,vkl(:,ik),ngp,igpig,wfmt,ngtc,&
+ wfir)
 ! generate the wavefunctions for occupied states at k+q
 allocate(wfmtq(npcmtmax,natmtot,nspinor,nst),wfgkq(ngkmax,nspinor,nst))
-call genwfsvp(.false.,.true.,nst,idx,ngridg,igfft,vkql,ngp,igpig,wfmtq,ngkmax, &
+call genwfsvp(.false.,.true.,nst,idx,ngdgc,igfc,vkql,ngp,igpig,wfmtq,ngkmax, &
  wfgkq)
 ! determine the overlap matrix for all occupied states
 allocate(oq(nst,nst))
@@ -51,6 +49,6 @@ call genolpq(nst,expqmt,ngp,igpig,wfmt,wfir,wfmtq,wfgkq,oq)
 z1=zmdet(nst,oq)
 ! determine the phase of the determinant and add to total polarisation
 pl=pl+atan2(aimag(z1),dble(z1))
-deallocate(igpig,wfmt,wfir,wfmtq,wfgkq,oq)
+deallocate(wfmt,wfir,wfmtq,wfgkq,oq)
 end subroutine
 
