@@ -7,8 +7,7 @@ subroutine potkst
 use modmain
 use modtddft
 implicit none
-! only adiabatic approximation currently available
+! adiabatic approximation to the exchange-correlation potential
 call potks(.true.)
-return
 end subroutine
 
