@@ -12,11 +12,9 @@ implicit none
 integer, intent(in) :: ik
 ! local variables
 integer ispn,recl
-! automatic arrays
-complex(8) pmat(nstsv,nstsv,3)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:,:),evecsv(:,:)
-complex(8), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:)
+complex(8), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:),pmat(:,:,:)
 ! get the eigenvectors from file
 allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
 call getevecfv(filext,ik,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
@@ -33,22 +31,24 @@ call genwfsv(.true.,.true.,nstsv,[0],ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
  apwalm,evecfv,evecsv,wfmt,ngkmax,wfgk)
 deallocate(evecfv,evecsv,apwalm)
 ! calculate the momentum matrix elements
+allocate(pmat(nstsv,nstsv,3))
 call genpmatk(ngk(:,ik),igkig(:,:,ik),vgkc(:,:,:,ik),wfmt,wfgk,pmat)
 deallocate(wfmt,wfgk)
 ! write the matrix elements in the second-variational basis
 !$OMP CRITICAL(u230)
 ! write to RAM disk if required
 if (ramdisk) then
-  call putrd('PMAT.OUT',ik,v1=vkl(:,ik),n1=nstsv,nzv=nstsv*nstsv*3,zva=pmat)
+  call putrd('PMAT.OUT',ik,v1=vkl(1:3,ik),n1=nstsv,nzv=nstsv*nstsv*3,zva=pmat)
 end if
 ! write to disk if required
 if (wrtdsk) then
 ! determine the record length
-  inquire(iolength=recl) vkl(:,1),nstsv,pmat
+  inquire(iolength=recl) vkl(1:3,1),nstsv,pmat
   open(230,file='PMAT.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
-  write(230,rec=ik) vkl(:,ik),nstsv,pmat
+  write(230,rec=ik) vkl(1:3,ik),nstsv,pmat
   close(230)
 end if
 !$OMP END CRITICAL(u230)
+deallocate(pmat)
 end subroutine
 
