@@ -15,16 +15,17 @@ integer is,ias,nthd
 ! external functions
 complex(8), external :: rcfmtinp
 ! interstitial contribution
-rcfinp=sum((cfunir(:)*rfir(:))*cfir(:))
+rcfinp=sum((cfunir(1:ngtot)*rfir(1:ngtot))*cfir(1:ngtot))
 rcfinp=rcfinp*(omega/dble(ngtot))
 ! muffin-tin contribution
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(is) REDUCTION(+:rcfinp) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ias=1,natmtot
   is=idxis(ias)
-  rcfinp=rcfinp+rcfmtinp(nrcmt(is),nrcmti(is),wrcmt(:,is),rfmt(:,ias), &
+  rcfinp=rcfinp+rcfmtinp(nrcmt(is),nrcmti(is),wr2cmt(:,is),rfmt(:,ias), &
    cfmt(:,ias))
 end do
 !$OMP END PARALLEL DO
