@@ -23,15 +23,15 @@ integer ik1,ik2,jk,iv(3)
 integer ist1,ist2
 real(8) t1,t2,t3,t4
 ! allocatable arays
-real(8), allocatable :: vclijji(:,:,:)
+real(8), allocatable :: vcl1221(:,:,:)
 ! calculate the prefactor
-if (rdmxctype.eq.0) then
+if (rdmxctype == 0) then
   engyx=0.d0
   return
-else if (rdmxctype.eq.1) then
+else if (rdmxctype == 1) then
 ! Hartree-Fock functional
   t1=0.5d0/occmax
-else if (rdmxctype.eq.2) then
+else if (rdmxctype == 2) then
 ! Power functional
   if (spinpol) then
     t1=0.5d0
@@ -46,10 +46,10 @@ else
 end if
 ! exchange-correlation energy
 engyx=0.d0
-allocate(vclijji(nstsv,nstsv,nkpt))
+allocate(vcl1221(nstsv,nstsv,nkpt))
 ! start loop over non-reduced k-points
 do ik1=1,nkptnr
-  call getvclijji(ik1,vclijji)
+  call getvcl1221(ik1,vcl1221)
 ! find the equivalent reduced k-point
   iv(:)=ivk(:,ik1)
   jk=ivkik(iv(1),iv(2),iv(3))
@@ -58,24 +58,24 @@ do ik1=1,nkptnr
    do ik2=1,nkpt
      do ist2=1,nstsv
 ! Hartree-Fock functional
-        if (rdmxctype.eq.1) then
+        if (rdmxctype == 1) then
           t2=t1*wkpt(ik2)*occsv(ist2,ik2)*occsv(ist1,jk)
 ! Power functional
-        else if (rdmxctype.eq.2) then
+        else if (rdmxctype == 2) then
           t3=occsv(ist2,ik2)*occsv(ist1,jk)
           t4=sum(abs(vkl(:,ik2)-vkl(:,ik1)))
-          if ((ist2.eq.ist1).and.(t4.lt.epslat)) then
+          if ((ist2 == ist1).and.(t4 < epslat)) then
             t2=(0.5d0/occmax)*wkpt(ik2)*t3
           else
             t2=t1*wkpt(ik2)*(t3**rdmalpha)
           end if
         end if
-        engyx=engyx-t2*vclijji(ist2,ist1,ik2)
+        engyx=engyx-t2*vcl1221(ist2,ist1,ik2)
       end do
     end do
   end do
 end do
-deallocate(vclijji)
+deallocate(vcl1221)
 end subroutine
 !EOC
 
