@@ -22,7 +22,7 @@ use modmpi
 implicit none
 ! local variables
 integer it
-if (maxitc.lt.1) return
+if (maxitc < 1) return
 ! begin iteration loop
 do it=1,maxitc
   if (mp_mpi) then
@@ -37,7 +37,7 @@ do it=1,maxitc
 ! calculate derivative of kinetic energy w.r.t. evecsv
   call rdmdkdc
 ! write the Coulomb matrix elements to file
-  call writevclijjk
+  call writevcl1223
 ! update evecsv, orthogonalise and write to file
   call rdmvaryc
 ! calculate the energy
