@@ -22,15 +22,15 @@ use modmpi
 implicit none
 ! local variables
 integer it,n
-if (maxitn.lt.1) return
+if (maxitn < 1) return
 ! write the Coulomb matrix elements to file
-call writevclijji
+call writevcl1221
 ! calculate derivative of kinetic energy w.r.t. evecsv
 call rdmdkdc
 ! begin iteration loop
 do it=1,maxitn
   if (mp_mpi) then
-    if (mod(it,10).eq.0) then
+    if (mod(it,10) == 0) then
       write(*,'("Info(rdmminn): iteration ",I4," of ",I4)') it,maxitn
     end if
   end if
