@@ -13,7 +13,7 @@ real(8), intent(out) :: a2f(nwplot)
 integer iw,ios
 open(50,file='ALPHA2F.OUT',form='FORMATTED',action='READ',status='OLD', &
  iostat=ios)
-if (ios.ne.0) then
+if (ios /= 0) then
   write(*,*)
   write(*,'("Error(readalpha2f): error opening ALPHA2F.OUT")')
   write(*,*)
@@ -21,7 +21,7 @@ if (ios.ne.0) then
 end if
 do iw=1,nwplot
   read(50,*,iostat=ios) w(iw),a2f(iw)
-  if (ios.ne.0) then
+  if (ios /= 0) then
     write(*,*)
     write(*,'("Error(readalpha2f): error reading from ALPHA2F.OUT")')
     write(*,'(" for frequency ",I6)') iw
