@@ -3,12 +3,10 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine readdyn(dynq)
+subroutine readdyn
 use modmain
 use modphonon
 implicit none
-! arguments
-complex(8), intent(out) :: dynq(nbph,nbph,nqpt)
 ! local variables
 logical exist
 integer iq,is,js,ia,ja
