@@ -43,7 +43,7 @@ real(8) scx,scy,scz
 real(8) scu,scu1,scu2,scu3
 real(8) solscf,zn
 real(8) axang(4),rot(3,3)
-real(8) v(3),t1
+real(8) rndavec,v(3),t1
 character(256) block,symb,str
 
 !------------------------!
@@ -100,6 +100,7 @@ nempty0=4.d0
 dnempty0=0.d0
 maxscl=200
 mixtype=3
+mixsave=.false.
 amixpm(1)=0.05d0
 amixpm(2)=1.d0
 ! Broyden parameters recommended by M. Meinert
@@ -152,6 +153,7 @@ atpopt=1
 maxatpstp=200
 tau0atp=0.2d0
 deltast=0.005d0
+avecref(:,:)=0.d0
 latvopt=0
 maxlatvstp=30
 tau0latv=0.2d0
@@ -171,8 +173,9 @@ evaltol=-1.d0
 epsband=1.d-12
 demaxbnd=2.5d0
 autolinengy=.false.
+deapw=0.2d0
+delorb=0.05d0
 dlefe=-0.1d0
-deapwlo=0.05d0
 bfieldc0(:)=0.d0
 dbfieldc0(:)=0.d0
 efieldc(:)=0.d0
@@ -256,7 +259,6 @@ esccut=-0.4d0
 gmaxrf=3.d0
 emaxrf=1.d6
 ntemp=40
-trimvg=.true.
 nvbse0=2
 ncbse0=3
 nvxbse=0
@@ -321,6 +323,7 @@ scu2=1.d0
 scu3=1.d0
 q0cut=0.d0
 rndbfcu=0.d0
+bfielduc(:)=0.d0
 efielduc(:)=0.d0
 tplotq0=.true.
 trdvclr=.false.
@@ -379,7 +382,7 @@ tafspt=.false.
 trdatdv=.false.
 atdfc=0.d0
 maxforce=-1.d0
-msmgmt=4
+msmgmt=0
 ntsorth=1000
 deltabf=0.5d0
 jtconst0=.false.
@@ -407,7 +410,7 @@ end if
 10 continue
 read(50,*,end=30) block
 ! check for a comment
-if ((scan(trim(block),'!') == 1).or.(scan(trim(block),'#') == 1)) goto 10
+if ((block(1:1) == '!').or.(block(1:1) == '#')) goto 10
 select case(trim(block))
 case('tasks')
   do i=1,maxtasks
@@ -465,15 +468,11 @@ case('fspecies')
   write(*,*)
   stop
 case('avec')
-  read(50,'(A)',err=20) str
-  read(str,*,err=20) avec(:,1)
-  read(str,*,iostat=ios) avec(:,1),davec(:,1)
-  read(50,'(A)',err=20) str
-  read(str,*,err=20) avec(:,2)
-  read(str,*,iostat=ios) avec(:,2),davec(:,2)
-  read(50,'(A)',err=20) str
-  read(str,*,err=20) avec(:,3)
-  read(str,*,iostat=ios) avec(:,3),davec(:,3)
+  do i=1,3
+    read(50,'(A)',err=20) str
+    read(str,*,err=20) avec(:,i)
+    read(str,*,iostat=ios) avec(:,i),davec(:,i)
+  end do
 case('scale')
   read(50,*,err=20) sc
 case('scale1')
@@ -514,7 +513,7 @@ case('ngridk')
   read(50,'(A)',err=20) str
   read(str,*,err=20) ngridk(:)
   read(str,*,iostat=ios) ngridk(:),dngridk(:)
-  if (any(ngridk(:) <= 0)) then
+  if (any(ngridk(:) < 1)) then
     write(*,*)
     write(*,'("Error(readinput): invalid ngridk : ",3I8)') ngridk
     write(*,*)
@@ -534,7 +533,7 @@ case('reducek')
   read(50,*,err=20) reducek
 case('ngridq')
   read(50,*,err=20) ngridq(:)
-  if (any(ngridq(:) <= 0)) then
+  if (any(ngridq(:) < 1)) then
     write(*,*)
     write(*,'("Error(readinput): invalid ngridq : ",3I8)') ngridq
     write(*,*)
@@ -613,15 +612,15 @@ case('socscf')
 case('xctype')
   read(50,'(A)',err=20) str
   str=trim(str)//' 0 0'
-  read(str,*,err=20) xctype
+  read(str,*,err=20) xctype(:)
 case('xctsp')
   read(50,'(A)',err=20) str
   str=trim(str)//' 0 0'
-  read(str,*,err=20) xctsp
+  read(str,*,err=20) xctsp(:)
 case('ktype')
   read(50,'(A)',err=20) str
   str=trim(str)//' 0 0'
-  read(str,*,err=20) ktype
+  read(str,*,err=20) ktype(:)
   if (ktype(3) /= 0) then
     write(*,*)
     write(*,'("Error(readinput): ktype(3) should be zero : ",I8)') ktype(3)
@@ -677,6 +676,8 @@ case('nempty','nempty0')
   end if
 case('mixtype')
   read(50,*,err=20) mixtype
+case('mixsave')
+  read(50,*,err=20) mixsave
 case('amixpm','beta0','betamax')
   if (trim(block) == 'amixpm') then
     read(50,*,err=20) amixpm(:)
@@ -741,9 +742,9 @@ case('molecule')
   read(50,*,err=20) molecule
 case('atoms')
   read(50,*,err=20) nspecies
-  if (nspecies <= 0) then
+  if (nspecies < 1) then
     write(*,*)
-    write(*,'("Error(readinput): nspecies <= 0 : ",I8)') nspecies
+    write(*,'("Error(readinput): nspecies < 1 : ",I8)') nspecies
     write(*,*)
     stop
   end if
@@ -758,9 +759,9 @@ case('atoms')
     read(50,*,err=20) spfname(is)
     spfname(is)=adjustl(spfname(is))
     read(50,*,err=20) natoms(is)
-    if (natoms(is) <= 0) then
+    if (natoms(is) < 1) then
       write(*,*)
-      write(*,'("Error(readinput): natoms <= 0 : ",I8)') natoms(is)
+      write(*,'("Error(readinput): natoms < 1 : ",I8)') natoms(is)
       write(*,'(" for species ",I4)') is
       write(*,*)
       stop
@@ -870,9 +871,9 @@ case('atpopt')
   read(50,*,err=20) atpopt
 case('maxatpstp','maxatmstp')
   read(50,*,err=20) maxatpstp
-  if (maxatpstp <= 0) then
+  if (maxatpstp < 1) then
     write(*,*)
-    write(*,'("Error(readinput): maxatpstp <= 0 : ",I8)') maxatpstp
+    write(*,'("Error(readinput): maxatpstp < 1 : ",I8)') maxatpstp
     write(*,*)
     stop
   end if
@@ -886,13 +887,17 @@ case('deltast')
     write(*,*)
     stop
   end if
+case('avecref')
+  read(50,*,err=20) avecref(:,1)
+  read(50,*,err=20) avecref(:,2)
+  read(50,*,err=20) avecref(:,3)
 case('latvopt')
   read(50,*,err=20) latvopt
 case('maxlatvstp')
   read(50,*,err=20) maxlatvstp
-  if (maxlatvstp <= 0) then
+  if (maxlatvstp < 1) then
     write(*,*)
-    write(*,'("Error(readinput): maxlatvstp <= 0 : ",I8)') maxlatvstp
+    write(*,'("Error(readinput): maxlatvstp < 1 : ",I8)') maxlatvstp
     write(*,*)
     stop
   end if
@@ -903,9 +908,9 @@ case('nstfsp')
   write(*,'("Info(readinput): variable ''nstfsp'' is no longer used")')
 case('lradstp')
   read(50,*,err=20) lradstp
-  if (lradstp <= 0) then
+  if (lradstp < 1) then
     write(*,*)
-    write(*,'("Error(readinput): lradstp <= 0 : ",I8)') lradstp
+    write(*,'("Error(readinput): lradstp < 1 : ",I8)') lradstp
     write(*,*)
     stop
   end if
@@ -985,16 +990,24 @@ case('demaxbnd')
   end if
 case('autolinengy')
   read(50,*,err=20) autolinengy
-case('dlefe')
-  read(50,*,err=20) dlefe
-case('deapwlo')
-  read(50,*,err=20) deapwlo
-  if (abs(deapwlo) < 1.d-8) then
+case('deapw')
+  read(50,*,err=20) deapw
+  if (abs(deapw) < 1.d-8) then
     write(*,*)
-    write(*,'("Error(readinput): invalid deapwlo : ",G18.10)') deapwlo
+    write(*,'("Error(readinput): invalid deapw : ",G18.10)') deapw
     write(*,*)
     stop
   end if
+case('delorb')
+  read(50,*,err=20) delorb
+  if (abs(delorb) < 1.d-8) then
+    write(*,*)
+    write(*,'("Error(readinput): invalid delorb : ",G18.10)') delorb
+    write(*,*)
+    stop
+  end if
+case('dlefe')
+  read(50,*,err=20) dlefe
 case('bfieldc')
   read(50,'(A)',err=20) str
   read(str,*,err=20) bfieldc0(:)
@@ -1079,9 +1092,9 @@ case('deltaph')
   end if
 case('phwrite')
   read(50,*,err=20) nphwrt
-  if (nphwrt <= 0) then
+  if (nphwrt < 1) then
     write(*,*)
-    write(*,'("Error(readinput): nphwrt <= 0 : ",I8)') nphwrt
+    write(*,'("Error(readinput): nphwrt < 1 : ",I8)') nphwrt
     write(*,*)
     stop
   end if
@@ -1214,7 +1227,7 @@ case('DFT+U','dft+u','lda+u')
       write(*,*)
       stop
     end if
-    if ((is <= 0).or.(is >= maxspecies)) then
+    if ((is < 1).or.(is >= maxspecies)) then
       write(*,*)
       write(*,'("Error(readinput): invalid species number in dft+u block : ", &
        &I8)') is
@@ -1504,7 +1517,8 @@ case('ntemp')
     stop
   end if
 case('trimvg')
-  read(50,*,err=20) trimvg
+  write(*,'("Info(readinput): variable ''trimvg'' is no longer used")')
+  read(50,*,err=20)
 case('rndstate','rndseed')
   read(50,*,err=20) rndstate(0)
   rndstate(0)=abs(rndstate(0))
@@ -1561,7 +1575,7 @@ case('lowq','highq','vhighq','uhighq')
 ! parameter set for very high-quality calculation
       rgkmax=max(rgkmax,9.d0)
       gmaxvr=max(gmaxvr,18.d0)
-      lmaxapw=max(lmaxapw,12)
+      lmaxapw=max(lmaxapw,11)
       lmaxo=max(lmaxo,8)
       nrmtscf=max(nrmtscf,2.d0)
       nxlo=max(nxlo,3)
@@ -1580,7 +1594,7 @@ case('lowq','highq','vhighq','uhighq')
 ! parameter set for ultra high-quality calculation
       rgkmax=max(rgkmax,10.d0)
       gmaxvr=max(gmaxvr,20.d0)
-      lmaxapw=max(lmaxapw,14)
+      lmaxapw=max(lmaxapw,12)
       lmaxo=max(lmaxo,9)
       nrmtscf=max(nrmtscf,4.d0)
       nxlo=max(nxlo,3)
@@ -1683,8 +1697,6 @@ case('epsdev')
 case('msmooth')
   read(50,*,err=20)
   write(*,'("Info(readinput): variable ''msmooth'' is no longer used")')
-  write(*,'(" setting trimvg to .true. instead")')
-  trimvg=.true.
 case('npmae')
   read(50,*,err=20) npmae0
 case('wrtvars')
@@ -1699,9 +1711,9 @@ case('tmomfix')
   stop
 case('tm3fix')
   read(50,*,err=20) ntmfix
-  if (ntmfix <= 0) then
+  if (ntmfix < 1) then
     write(*,*)
-    write(*,'("Error(readinput): ntmfix <= 0 : ",I8)') ntmfix
+    write(*,'("Error(readinput): ntmfix < 1 : ",I8)') ntmfix
     write(*,*)
     stop
   end if
@@ -1711,10 +1723,10 @@ case('tm3fix')
   allocate(wkprfix(ntmfix))
   do i=1,ntmfix
     read(50,*,err=20) is,ia,l
-    if ((is <= 0).or.(ia <= 0).or.(l < 0)) then
+    if ((is < 1).or.(ia < 1).or.(l < 0)) then
       write(*,*)
       write(*,'("Error(readinput): invalid is, ia or l in tm3fix block : ",&
-       &4I8)') is,ia,l
+       &3I8)') is,ia,l
       write(*,*)
       stop
     end if
@@ -1743,7 +1755,7 @@ case('rotavec')
   read(50,*,err=20) axang(:)
 case('tstime')
   read(50,*,err=20) tstime
-  if (tstime < 0.d0) then
+  if (tstime <= 0.d0) then
     write(*,*)
     write(*,'("Error(readinput): tstime <= 0 : ",G18.10)') tstime
     write(*,*)
@@ -1902,6 +1914,8 @@ case('q0cut')
   end if
 case('rndbfcu')
   read(50,*,err=20) rndbfcu
+case('bfielduc')
+  read(50,*,err=20) bfielduc
 case('efielduc')
   read(50,*,err=20) efielduc
 case('tplotq0')
@@ -1921,17 +1935,17 @@ case('actype')
   read(50,*,err=20) actype
 case('npole')
   read(50,*,err=20) npole
-  if (npole <= 0) then
+  if (npole < 1) then
     write(*,*)
-    write(*,'("Error(readinput): npole <= 0 : ",I8)') npole
+    write(*,'("Error(readinput): npole < 1 : ",I8)') npole
     write(*,*)
     stop
   end if
 case('nspade')
   read(50,*,err=20) nspade
-  if (nspade <= 0) then
+  if (nspade < 1) then
     write(*,*)
-    write(*,'("Error(readinput): nspade <= 0 : ",I8)') nspade
+    write(*,'("Error(readinput): nspade < 1 : ",I8)') nspade
     write(*,*)
     stop
   end if
@@ -1966,16 +1980,14 @@ case('maxlvl','omp_max_active_levels','OMP_MAX_ACTIVE_LEVELS')
 case('stable')
   read(50,*,err=20) lv
   if (lv) then
-    trimvg=.true.
     autolinengy=.true.
     mrmtav=1
     lmaxapw=max(lmaxapw,10)
     gmaxvr=max(gmaxvr,24.d0)
-    msmgmt=max(msmgmt,8)
+    msmgmt=max(msmgmt,4)
     if (mp_mpi) then
       write(*,*)
       write(*,'("Info(readinput): parameters set by stable option")')
-      write(*,'(" trimvg : ",L1)') trimvg
       write(*,'(" autolinengy : ",L1)') autolinengy
       write(*,'(" mrmtav : ",I4)') mrmtav
       write(*,'(" lmaxapw : ",I4)') lmaxapw
@@ -1989,7 +2001,7 @@ case('metagga')
     lmaxi=max(lmaxi,2)
     gmaxvr=max(gmaxvr,16.d0)
     nrmtscf=max(nrmtscf,3.d0)
-    msmgmt=max(msmgmt,8)
+    msmgmt=max(msmgmt,4)
     epspot=1.d6
     epsengy=min(epsengy,1.d-6)
     if (mp_mpi) then
@@ -2230,6 +2242,8 @@ if (rndavec > 0.d0) then
     end do
   end do
 end if
+! check if reference lattice vectors should be used
+tavref=(any(abs(avecref(:,:)) > epslat))
 ! case of isolated molecule
 if (molecule) then
 ! convert atomic positions from Cartesian to lattice coordinates
