@@ -14,7 +14,7 @@ integer its,ios
 real(8) times_,t1
 open(50,file='JTOT_TD.OUT',form='FORMATTED',action='READ',status='OLD', &
  iostat=ios)
-if (ios.ne.0) then
+if (ios /= 0) then
   write(*,*)
   write(*,'("Error(readjtot): error opening JTOT_TD.OUT")')
   write(*,*)
@@ -23,7 +23,7 @@ end if
 do its=1,ntimes-1
   read(50,*) times_,jt(:,its)
   t1=abs(times(its)-times_)
-  if (t1.gt.1.d-10) then
+  if (t1 > 1.d-10) then
     write(*,*)
     write(*,'("Error(readjtot): time step mismatch for step number ",I8)') its
     write(*,'(" internal    : ",G18.10)') times(its)
