@@ -15,6 +15,6 @@ do ias=1,natmtot
   is=idxis(ias)
   rfmt2(1:npmt(is),ias)=rfmt1(1:npmt(is),ias)
 end do
-rfir2(:)=rfir1(:)
+rfir2(1:ngtot)=rfir1(1:ngtot)
 end subroutine
 
