@@ -39,12 +39,12 @@ do i=0,1; do j=0,1; do k=0,1
 ! H+k-vector at corner of box
   v1(:)=dble(ivhb(:,i,j,k))+vkl(:,jk)
 ! store the origin of the box
-  if ((i.eq.0).and.(j.eq.0).and.(k.eq.0)) v0(:)=v1(:)
+  if ((i == 0).and.(j == 0).and.(k == 0)) v0(:)=v1(:)
 ! vector in Cartesian coordinates
   v2(:)=bvec(:,1)*v1(1)+bvec(:,2)*v1(2)+bvec(:,3)*v1(3)
 ! check length is within range
   t1=sqrt(v2(1)**2+v2(2)**2+v2(3)**2)
-  if (t1.gt.hkmax) cycle
+  if (t1 > hkmax) cycle
 ! find the lattice symmetry which maps the non-reduced to reduced k-point
   call findkpt(vkl(:,jk),isym,ik)
 ! index to spatial rotation in lattice point group
@@ -55,7 +55,7 @@ do i=0,1; do j=0,1; do k=0,1
     t1=abs(v2(1)-vhkl(1,ihk,1,ik)) &
       +abs(v2(2)-vhkl(2,ihk,1,ik)) &
       +abs(v2(3)-vhkl(3,ihk,1,ik))
-    if (t1.lt.epslat) then
+    if (t1 < epslat) then
       fb(i,j,k)=rfhk(ihk,ik)
       exit
     end if
