@@ -12,14 +12,14 @@ real(8), intent(in) :: rfmt(npmtmax)
 real(8), intent(out) :: fr(nrmtmax)
 ! local variables
 integer iro,i0,i1
-if (lm.gt.lmmaxi) then
+if (lm > lmmaxi) then
   fr(1:nri)=0.d0
 else
   i1=lmmaxi*(nri-1)+lm
   fr(1:nri)=rfmt(lm:i1:lmmaxi)
 end if
 iro=nri+1
-if (lm.gt.lmmaxo) then
+if (lm > lmmaxo) then
   fr(iro:nr)=0.d0
 else
   i0=lmmaxi*nri+lm
