@@ -11,15 +11,13 @@ integer, intent(in) :: nr,nri
 real(8), intent(in) :: rfmt1(*)
 real(8), intent(out) :: rfmt2(*)
 ! local variables
-integer nro,i
+integer i
 ! transform the inner part of the muffin-tin
 call dgemm('N','N',lmmaxi,nri,lmmaxi,1.d0,rfshti,lmmaxi,rfmt1,lmmaxi,0.d0, &
  rfmt2,lmmaxi)
 ! transform the outer part of the muffin-tin
-nro=nr-nri
 i=lmmaxi*nri+1
-call dgemm('N','N',lmmaxo,nro,lmmaxo,1.d0,rfshto,lmmaxo,rfmt1(i),lmmaxo,0.d0, &
- rfmt2(i),lmmaxo)
-return
+call dgemm('N','N',lmmaxo,nr-nri,lmmaxo,1.d0,rfshto,lmmaxo,rfmt1(i),lmmaxo, &
+ 0.d0,rfmt2(i),lmmaxo)
 end subroutine
 
