@@ -41,7 +41,7 @@ do ias=1,natmtot
     i1=lmmaxo*(nr-iro)+i0
     rhomt(i0:i1:lmmaxo,ias)=rhomt(i0:i1:lmmaxo,ias)+rhocr(iro:nr,ias,ispn)
 ! compute the core charge inside the muffin-tins
-    t1=dot_product(wrmt(1:nr,is),rhocr(1:nr,ias,ispn))
+    t1=sum(wr2mt(1:nr,is)*rhocr(1:nr,ias,ispn))
     sm=sm+fourpi*y00*t1
   end do
 ! core leakage charge
@@ -50,7 +50,7 @@ do ias=1,natmtot
   if (spincore) then
 ! compute the moment in the muffin-tin
     do idm=1,ndmag
-      v(idm)=rfmtint(nr,nri,wrmt(:,is),magmt(:,ias,idm))
+      v(idm)=rfmtint(nr,nri,wr2mt(:,is),magmt(:,ias,idm))
     end do
 ! normalise
     if (ncmag) then
@@ -58,17 +58,17 @@ do ias=1,natmtot
     else
       t1=abs(v(1))
     end if
-    if (t1 > 1.d-10) v(:)=v(:)/t1
+    if (t1 > 1.d-10) v(1:ndmag)=v(1:ndmag)/t1
 ! add the core magnetisation to the total
     i=1
     do ir=1,nri
       t1=rhocr(ir,ias,1)-rhocr(ir,ias,2)
-      magmt(i,ias,:)=magmt(i,ias,:)+t1*v(:)
+      magmt(i,ias,1:ndmag)=magmt(i,ias,1:ndmag)+t1*v(1:ndmag)
       i=i+lmmaxi
     end do
     do ir=iro,nr
       t1=rhocr(ir,ias,1)-rhocr(ir,ias,2)
-      magmt(i,ias,:)=magmt(i,ias,:)+t1*v(:)
+      magmt(i,ias,1:ndmag)=magmt(i,ias,1:ndmag)+t1*v(1:ndmag)
       i=i+lmmaxo
     end do
   end if
