@@ -26,9 +26,9 @@ use modomp
 !   wavefunction is obtained in terms of its $(l,m)$-components from both the
 !   APW and local-orbital functions. Using a backward spherical harmonic
 !   transform (SHT), the wavefunction is converted to real-space and the density
-!   obtained from its modulus squared. A similar proccess is used for the
-!   intersitial density in which the wavefunction in real-space is obtained from
-!   a Fourier transform of the APW functions. See routines {\tt wfmtsv},
+!   obtained from its modulus squared. A similar process is used for the
+!   interstitial density in which the wavefunction in real-space is obtained
+!   from a Fourier transform of the APW functions. See routines {\tt wfmtsv},
 !   {\tt genshtmat} and {\tt eveqn}.
 !
 ! !REVISION HISTORY:
@@ -83,7 +83,7 @@ do ias=1,natmtot
   call wfmtsv(.false.,lradstp,is,ias,nst,idx,ngp,apwalm,evecfv,evecsv,npcmtmax,&
    wfmt)
 !$OMP END SINGLE
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
   do j=1,nst
     k=idx(j)
     wo=occsvp(k)*wppt
@@ -110,7 +110,7 @@ end do
 !------------------------------------------------!
 !     interstitial density and magnetisation     !
 !------------------------------------------------!
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
 do j=1,nst
   k=idx(j)
   wo=occsvp(k)*wppt/omega
@@ -123,11 +123,11 @@ do j=1,nst
       do ist=1,nstfv
         i=(ispn-1)*nstfv+ist
         z1=evecsv(i,k)
-        if (abs(dble(z1))+abs(aimag(z1)) > epsocc) then
+        if (abs(dble(z1))+abs(aimag(z1)) > 1.d-10) then
           wfgp(1:n)=wfgp(1:n)+z1*evecfv(1:n,ist,jspn)
         end if
       end do
-      wfir(:,ispn)=0.d0
+      wfir(1:ngtc,ispn)=0.d0
       do igp=1,n
         wfir(igfc(igpig(igp,jspn)),ispn)=wfgp(igp)
       end do
@@ -136,7 +136,7 @@ do j=1,nst
     end do
   else
 ! spin-unpolarised wavefunction
-    wfir(:,1)=0.d0
+    wfir(1:ngtc,1)=0.d0
     do igp=1,ngp(1)
       wfir(igfc(igpig(igp,1)),1)=evecfv(igp,k,1)
     end do
@@ -220,7 +220,7 @@ integer, intent(in) :: n
 real(8), intent(in) :: wo
 complex(8), intent(in) :: wf(n)
 real(8), intent(inout) :: rho(n)
-rho(:)=rho(:)+wo*(dble(wf(:))**2+aimag(wf(:))**2)
+rho(1:n)=rho(1:n)+wo*(dble(wf(1:n))**2+aimag(wf(1:n))**2)
 end subroutine
 
 end subroutine
