@@ -14,12 +14,13 @@ integer(omp_lock_kind), intent(inout) :: lock(nqpt)
 complex(8), intent(in) :: evecu(nstulr,nstulr)
 ! local variables
 integer ik,ikpa,jkpa
-integer ist,jst,i,j
+integer nst,ist,jst,i,j
 integer ngk0,is,ias
 integer npc,ir,nthd
 real(8) ts0,ts1
 real(4) wo
 ! automatic arrays
+integer idx(nstsv)
 complex(8) zfft(nqpt)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
@@ -39,11 +40,21 @@ allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot))
 call match(ngk0,vgkc(:,:,1,ik),gkc(:,1,ik),sfacgk(:,:,1,ik),apwalm)
 allocate(evectv(nstsv,nstsv,nqpt),evecsvt(nstsv,nstsv))
 allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv),wfir(ngtc,nspinor,nstsv))
+! loop over long-range states in subsets of size nstsv
 do jkpa=1,nkpa
+! number of and index to occupied states in subset
+  nst=0
   do jst=1,nstsv
     j=(jkpa-1)*nstsv+jst
+    if (abs(occulr(j,ik0)) < epsocc) cycle
+    nst=nst+1
+    idx(nst)=jst
+  end do
+  if (nst == 0) cycle
+  do jst=1,nst
+    j=(jkpa-1)*nstsv+idx(jst)
     do ist=1,nstsv
-      zfft(:)=0.d0
+      zfft(1:nqpt)=0.d0
       do ikpa=1,nkpa
         i=(ikpa-1)*nstsv+ist
 ! store the long-range state in FFT Q-space
@@ -51,7 +62,7 @@ do jkpa=1,nkpa
       end do
 ! Fourier transform to R-space
       call zfftifc(3,ngridq,1,zfft)
-      evectv(ist,jst,:)=zfft(:)
+      evectv(ist,jst,1:nqpt)=zfft(1:nqpt)
     end do
   end do
 ! loop over R-points
@@ -60,17 +71,17 @@ do jkpa=1,nkpa
     call zgemm('N','N',nstsv,nstsv,nstsv,zone,evecsv,nstsv,evectv(:,:,ir), &
      nstsv,zzero,evecsvt,nstsv)
 ! generate the wavefunctions in single-precision
-    call genwfsv_sp(.false.,.false.,nstsv,[0],ngdgc,igfc,ngk0,igkig(:,1,ik), &
+    call genwfsv_sp(.false.,.false.,nst,idx,ngdgc,igfc,ngk0,igkig(:,1,ik), &
      apwalm,evecfv,evecsvt,wfmt,ngtc,wfir)
 ! parallel loop over states
     call holdthd(nstsv,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(j,wo,ias,is,npc) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
-    do jst=1,nstsv
-      j=(jkpa-1)*nstsv+jst
+    do jst=1,nst
+      j=(jkpa-1)*nstsv+idx(jst)
       wo=occulr(j,ik0)*wkpt(ik)
-      if (abs(wo) < epsocc) cycle
 ! add to the density and magnetisation
       call omp_set_lock(lock(ir))
 ! muffin-tin part
@@ -168,7 +179,7 @@ integer, intent(in) :: n
 real(4), intent(in) :: wo
 complex(4), intent(in) :: wf(n)
 real(8), intent(inout) :: rho(n)
-rho(:)=rho(:)+wo*(real(wf(:))**2+aimag(wf(:))**2)
+rho(1:n)=rho(1:n)+wo*(real(wf(1:n))**2+aimag(wf(1:n))**2)
 end subroutine
 
 end subroutine
