@@ -39,7 +39,7 @@ end if
 ! error in average density
 t1=(chgtot-chgcalc)/omega
 ! add the constant difference to the density
-t2=t1/y00
+t2=t1*y00i
 do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
