@@ -14,8 +14,8 @@ complex(8), intent(inout) :: dmat2(ld,nspinor,ld,nspinor)
 integer lds,ispn,jspn,p
 integer lmmax,l,lm1,lm2,nm
 real(8), parameter :: eps=1.d-8
-real(8) ang(3),angi(3)
-real(8) rot(3,3),det,v(3),th
+real(8) det,ang(3),angi(3)
+real(8) v(3),th
 complex(8), parameter :: zzero=(0.d0,0.d0),zone=(1.d0,0.d0)
 complex(8) su2(2,2),a(2,2),b(2,2)
 ! allocatable arrays
@@ -27,15 +27,14 @@ allocate(dm(ld,nspinor,ld,nspinor))
 allocate(c(lmmax,lmmax),d(lmmax,lmmax))
 ! find the determinant of the spatial rotation matrix
 det=r3mdet(rspl)
+! calculate the Euler angles of the proper rotation
 if (det > 0.d0) then
   p=1
+  call roteuler(rspl,ang)
 else
   p=-1
+  call roteuler(-rspl(:,:),ang)
 end if
-! make the rotation matrix proper
-rot(:,:)=dble(p)*rspl(:,:)
-! compute the Euler angles of the spatial rotation
-call roteuler(rot,ang)
 ! inverse rotation: the matrix is to be rotated, not the spherical harmonics
 angi(1)=-ang(3)
 angi(2)=-ang(2)
