@@ -54,7 +54,7 @@ case(5)
   sdelta=sdelta_lr(x)
 case default
   write(*,*)
-  write(*,'("Error(sdelta): sytpe not defined : ",I8)') stype
+  write(*,'("Error(sdelta): stype not defined : ",I8)') stype
   write(*,*)
   stop
 end select
@@ -95,7 +95,7 @@ case(5)
   sdescr='Lorentzian'
 case default
   write(*,*)
-  write(*,'("Error(getsdata): sytpe not defined : ",I8)') stype
+  write(*,'("Error(getsdata): stype not defined : ",I8)') stype
   write(*,*)
   stop
 end select
