@@ -33,9 +33,9 @@ real(8), intent(out) :: tp(2,n)
 integer k
 real(8), parameter :: pi=3.1415926535897932385d0
 real(8) z,dz,p,dp
-if (n <= 0) then
+if (n < 1) then
   write(*,*)
-  write(*,'("Error(sphcover): n <= 0 : ",I8)') n
+  write(*,'("Error(sphcover): n < 1 : ",I8)') n
   write(*,*)
   stop
 end if
