@@ -14,7 +14,7 @@ real(8) x0,x1,x2,x3,y0,y1,y2,y3
 real(8) t0,t1,t2,t3,t4,t5,t6,t7
 ! external functions
 real(8), external :: polynm
-if (n.le.4) then
+if (n <= 4) then
   splint=polynm(-1,n,x,f,x(n))
   return
 end if
