@@ -25,12 +25,11 @@ do iqss=1,nqpt
   end if
 end do
 iqss=0
-write(*,*)
 write(*,'("Info(sstask): nothing more to do")')
 10 continue
 ! broadcast to all other processes
 call mpi_bcast(iqss,1,mpi_integer,0,mpicom,ierror)
-if (iqss.eq.0) then
+if (iqss == 0) then
   fext='.OUT'
 else
   call ssfext(iqss,fext)
