@@ -32,8 +32,8 @@ call init1
 call init2
 call init3
 ! check q-vector is commensurate with k-point grid
-v(:)=dble(ngridk(:))*vecql(:)
-v(:)=abs(v(:)-nint(v(:)))
+v(1:3)=dble(ngridk(1:3))*vecql(1:3)
+v(1:3)=abs(v(1:3)-nint(v(1:3)))
 if ((v(1) > epslat).or.(v(2) > epslat).or.(v(3) > epslat)) then
   write(*,*)
   write(*,'("Error(tddftlr): q-vector incommensurate with k-point grid")')
@@ -68,7 +68,7 @@ deallocate(vgqc)
 ! generate the regularised Coulomb Green's function in G+q-space
 allocate(gclgq(ngrf))
 call gengclgq(.true.,iq,ngrf,gqc,gclgq)
-gclgq(:)=sqrt(gclgq(:))
+gclgq(1:ngrf)=sqrt(gclgq(1:ngrf))
 ! matrix sizes
 if (tq0) then
 ! for q = 0 the head is a 3 x 3 matrix and the wings are 3 x ngrf
@@ -86,9 +86,10 @@ do iw=1,nwrf
   call omp_init_lock(lock(iw))
 end do
 ! compute v¹⸍² χ₀ v¹⸍² (the symmetric version of v χ₀)
-vchi0(:,:,:)=0.d0
+vchi0(1:nm,1:nm,1:nwrf)=0.d0
 call holdthd(nkptnr/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP SCHEDULE(DYNAMIC) &
 !$OMP NUM_THREADS(nthd)
 do ik=1,nkptnr
 ! distribute among MPI processes
@@ -113,15 +114,15 @@ if (np_mpi > 1) then
    ierror)
 end if
 ! calculate symmetric ϵ_0 = 1 - v¹⸍² χ₀ v¹⸍²
-eps0(:,:,:)=-vchi0(:,:,:)
+eps0(1:nm,1:nm,1:nwrf)=-vchi0(1:nm,1:nm,1:nwrf)
 do i=1,nm
-  eps0(i,i,:)=eps0(i,i,:)+1.d0
+  eps0(i,i,1:nwrf)=eps0(i,i,1:nwrf)+1.d0
 end do
 ! initialise ϵ for use with the bootstrap functional
 if (any(fxctype(1) == [210,211])) then
-  epsi(:,:,:)=vchi0(:,:,:)
+  epsi(1:nm,1:nm,1:nwrf)=vchi0(1:nm,1:nm,1:nwrf)
   do i=1,nm
-    epsi(i,i,:)=epsi(i,i,:)+1.d0
+    epsi(i,i,1:nwrf)=epsi(i,i,1:nwrf)+1.d0
   end do
 end if
 allocate(a(nm,nm))
@@ -133,7 +134,7 @@ call genvfxc(tq0,.true.,gclgq,nm,vchi0,eps0,epsi,vfxc)
 ! begin loop over frequencies
 do iw=1,nwrf
 ! compute 1 - v¹⸍² χ₀ v¹⸍² - v⁻¹⸍² f_xc v⁻¹⸍² v χ₀
-  a(:,:)=eps0(:,:,iw)-vfxc(:,:,iw)
+  a(1:nm,1:nm)=eps0(1:nm,1:nm,iw)-vfxc(1:nm,1:nm,iw)
 ! invert this matrix
   call zminv(nm,a)
 ! left multiply by v¹⸍² χ₀ v¹⸍²
@@ -152,11 +153,13 @@ if (fxctype(1) == 210) then
     write(*,*)
     stop
   end if
-  if (mod(it,10) == 0) then
-    write(*,'("Info(tddftlr): done ",I4," bootstrap iterations")') it
-    t1=dble(vfxc(1,1,1))
-    write(*,'(" head of matrix v⁻¹⸍² f_xc v⁻¹⸍² : ",G18.10)') t1
-    write(*,'("  multiplied by -4π gives α : ",G18.10)') -fourpi*t1
+  if (mp_mpi) then
+    if (mod(it,10) == 0) then
+      write(*,'("Info(tddftlr): done ",I4," bootstrap iterations")') it
+      t1=dble(vfxc(1,1,1))
+      write(*,'(" head of matrix v⁻¹⸍² f_xc v⁻¹⸍² : ",G18.10)') t1
+      write(*,'("  multiplied by -4π gives α : ",G18.10)') -fourpi*t1
+    end if
   end if
 ! check for convergence
   t1=abs(vfxcp)-abs(vfxc(1,1,1))
@@ -172,7 +175,7 @@ deallocate(ylmgq,sfacgq)
 deallocate(vchi0,vfxc)
 ! invert ϵ⁻¹ to find ϵ and store in array eps0
 do iw=1,nwrf
-  eps0(:,:,iw)=epsi(:,:,iw)
+  eps0(1:nm,1:nm,iw)=epsi(1:nm,1:nm,iw)
   call zminv(nm,eps0(:,:,iw))
 end do
 if (mp_mpi) then
@@ -237,7 +240,7 @@ if (mp_mpi) then
       close(50)
     end do
     allocate(zw(nwrf))
-! output the Faraday angle components Delta delta and Delta beta
+! output the Faraday angle parameters Δδ and Δβ
     do iw=2,nwrf
       zw(iw)=0.5d0*zi*epsm(1,2,iw)/sqrt(epsm(1,1,iw))
     end do
