@@ -50,9 +50,9 @@ do i=0,999
       write(*,*)
       error stop
     end if
-    if (nv <= 0) then
+    if (nv < 1) then
       write(*,*)
-      write(*,'("Error(testcheck): nv <= 0 : ",I8)') nv
+      write(*,'("Error(testcheck): nv < 1 : ",I8)') nv
       write(*,*)
       error stop
     end if
