@@ -22,8 +22,16 @@ complex(4), allocatable :: crhomt(:,:)
 ! external functions
 complex(8), external :: zcfmtinp
 allocate(crhomt(npcmtmax,nstsv))
+! zero the upper triangular matrix elements
+do ist2=1,nstsv
+  v(1:ist2,ist2)=0.d0
+end do
 call holdthd(nstsv,nthd)
-v(:,:)=0.d0
+!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PRIVATE(cfmt,is,ia,ias) &
+!$OMP PRIVATE(nrc,nrci,npc) &
+!$OMP PRIVATE(ist1,ist2,ist3,m) &
+!$OMP NUM_THREADS(nthd)
 do is=1,nspecies
   nrc=nrcmt(is)
   nrci=nrcmti(is)
@@ -34,11 +42,10 @@ do is=1,nspecies
       if (spcore(ist3,is)) then
         do m=-ksp(ist3,is),ksp(ist3,is)-1
 ! generate the core wavefunction in spherical coordinates (pass in m-1/2)
+!$OMP SINGLE
           call wavefcr(.false.,lradstp,is,ia,ist3,m,npcmtmax,wfcr)
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(cfmt,ist1,ist2) &
-!$OMP NUM_THREADS(nthd)
-!$OMP DO
+!$OMP END SINGLE
+!$OMP DO SCHEDULE(DYNAMIC)
           do ist1=1,nstsv
 ! calculate the complex overlap density in spherical harmonics
             if (spinpol) then
@@ -50,22 +57,22 @@ do is=1,nspecies
             call cfsht(nrc,nrci,cfmt,crhomt(:,ist1))
           end do
 !$OMP END DO
-!$OMP DO
+!$OMP DO SCHEDULE(DYNAMIC)
           do ist2=1,nstsv
             call cpotclmt(nrc,nrci,nrcmtmax,rlcmt(:,:,is),wprcmt(:,:,is), &
              crhomt(:,ist2),cfmt)
             do ist1=1,ist2
-              v(ist1,ist2)=v(ist1,ist2)-zcfmtinp(nrc,nrci,wrcmt(:,is), &
+              v(ist1,ist2)=v(ist1,ist2)-zcfmtinp(nrc,nrci,wr2cmt(:,is), &
                crhomt(:,ist1),cfmt)
             end do
           end do
 !$OMP END DO
-!$OMP END PARALLEL
         end do
       end if
     end do
   end do
 end do
+!$OMP END PARALLEL
 call freethd(nthd)
 do ist1=1,nstsv
 ! set the lower triangular part of the matrix
@@ -76,9 +83,9 @@ do ist1=1,nstsv
   v(ist1,ist1)=dble(v(ist1,ist1))
 end do
 ! scale the Coulomb matrix elements in the case of a hybrid functional
-if (hybrid) v(:,:)=hybridc*v(:,:)
+if (hybrid) v(1:nstsv,1:nstsv)=hybridc*v(1:nstsv,1:nstsv)
 ! add to input matrix
-vmat(:,:)=vmat(:,:)+v(:,:)
+vmat(1:nstsv,1:nstsv)=vmat(1:nstsv,1:nstsv)+v(1:nstsv,1:nstsv)
 deallocate(crhomt)
 return
 
@@ -89,7 +96,7 @@ implicit none
 integer, intent(in) :: n
 complex(4), intent(in) :: wf1(n),wf2(n)
 complex(4), intent(out) :: crho(n)
-crho(:)=conjg(wf1(:))*wf2(:)
+crho(1:n)=conjg(wf1(1:n))*wf2(1:n)
 end subroutine
 
 pure subroutine crho2(n,wf11,wf12,wf21,wf22,crho)
@@ -97,7 +104,7 @@ implicit none
 integer, intent(in) :: n
 complex(4), intent(in) :: wf11(n),wf12(n),wf21(n),wf22(n)
 complex(4), intent(out) :: crho(n)
-crho(:)=conjg(wf11(:))*wf21(:)+conjg(wf12(:))*wf22(:)
+crho(1:n)=conjg(wf11(1:n))*wf21(1:n)+conjg(wf12(1:n))*wf22(1:n)
 end subroutine
 
 end subroutine
