@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine wavefcr(tsh,lrstp,is,ia,ist,m,ld,wfcr)
+pure subroutine wavefcr(tsh,lrstp,is,ia,ist,m,ld,wfcr)
 use modmain
 implicit none
 ! arguments
@@ -15,20 +15,11 @@ integer, intent(in) :: ld
 complex(4), intent(out) :: wfcr(ld,2)
 ! local variables
 integer ias,nr,nri,ir
-integer k,l,lm,lm1,lm2
+integer k,l,lm1,lm2
 integer i,i1,i2
 real(8) c1,c2,t0,t1,t2
 l=lsp(ist,is)
 k=ksp(ist,is)
-if (((k /= l+1).and.(k /= l)).or.(m < -k).or.(m > k-1)) then
-  write(*,*)
-  write(*,'("Error(wavefcr): mismatched l, k or m : ",3I4)') l,k,m
-  write(*,'(" for species ",I4)') is
-  write(*,'(" atom ",I4)') ia
-  write(*,'(" and state ",I6)') ist
-  write(*,*)
-  stop
-end if
 if (l > lmaxo) then
   wfcr(:,:)=0.e0
   return
@@ -58,14 +49,9 @@ nr=nrmt(is)
 nri=nrmti(is)
 ! zero the wavefunction
 if (lrstp == 1) then
-  wfcr(1:npmt(is),:)=0.e0
-else if (lrstp == lradstp) then
-  wfcr(1:npcmt(is),:)=0.e0
+  wfcr(1:npmt(is),1:2)=0.e0
 else
-  write(*,*)
-  write(*,'("Error(wavefcr): invalid lrstp : ",I8)') lrstp
-  write(*,*)
-  stop
+  wfcr(1:npcmt(is),1:2)=0.e0
 end if
 !----------------------------------!
 !     inner part of muffin-tin     !
@@ -88,16 +74,8 @@ do ir=1,nri,lrstp
   else
     t1=t0*c1
     t2=t0*c2
-    if (lm1 > 0) then
-      do lm=1,lmmaxi
-        wfcr(i+lm,1)=t1*zbshti(lm,lm1)
-      end do
-    end if
-    if (lm2 > 0) then
-      do lm=1,lmmaxi
-        wfcr(i+lm,2)=t2*zbshti(lm,lm2)
-      end do
-    end if
+    if (lm1 > 0) wfcr(i+1:i+lmmaxi,1)=t1*zbshti(1:lmmaxi,lm1)
+    if (lm2 > 0) wfcr(i+1:i+lmmaxi,2)=t2*zbshti(1:lmmaxi,lm2)
     i=i+lmmaxi
   end if
 end do
@@ -124,16 +102,8 @@ do ir=nri+lrstp,nr,lrstp
   else
     t1=t0*c1
     t2=t0*c2
-    if (lm1 > 0) then
-      do lm=1,lmmaxo
-        wfcr(i+lm,1)=t1*zbshto(lm,lm1)
-      end do
-    end if
-    if (lm2 > 0) then
-      do lm=1,lmmaxo
-        wfcr(i+lm,2)=t2*zbshto(lm,lm2)
-      end do
-    end if
+    if (lm1 > 0) wfcr(i+1:i+lmmaxo,1)=t1*zbshto(1:lmmaxo,lm1)
+    if (lm2 > 0) wfcr(i+1:i+lmmaxo,2)=t2*zbshto(1:lmmaxo,lm2)
     i=i+lmmaxo
   end if
 end do
