@@ -67,6 +67,7 @@ do l=0,lmaxo
     i=npci+lm
     do io=1,apword(l,is)
       z1=zdotu(ngp,evecfv,1,apwalm(:,io,lm),1)
+      if (abs(dble(z1))+abs(aimag(z1)) < 1.d-10) cycle
       if (l <= lmaxi) then
         call zfzrf(nrci,z1,apwfr(1,1,io,l,ias),lmmaxi,wfmt(lm))
       end if
@@ -82,6 +83,7 @@ do ilo=1,nlorb(is)
   do lm=l**2+1,(l+1)**2
     i=npci+lm
     z1=evecfv(ngp+idxlo(lm,ilo,ias))
+    if (abs(dble(z1))+abs(aimag(z1)) < 1.d-10) cycle
     if (l <= lmaxi) then
       call zfzrf(nrci,z1,lofr(1,1,ilo,ias),lmmaxi,wfmt(lm))
     end if
@@ -100,7 +102,7 @@ complex(8), intent(in) :: z
 real(8), intent(in) :: rf(lradstp,n)
 integer, intent(in) :: ld
 complex(8), intent(inout) :: zf(ld,n)
-zf(1,:)=zf(1,:)+z*rf(1,:)
+zf(1,1:n)=zf(1,1:n)+z*rf(1,1:n)
 end subroutine
 
 end subroutine
