@@ -30,10 +30,10 @@ integer l12,l22,l32,l42
 integer k,k1,k2,l1,l2,l3
 real(8) sgn,sm,t1
 ! external functions
-real(8), external :: factnm,factr
+real(8), external :: factn,factr
 ! check input variables
-if ((j12.lt.0).or.(j22.lt.0).or.(j32.lt.0).or.(abs(m12).gt.j12).or. &
- (abs(m22).gt.j22).or.(abs(m32).gt.j32)) then
+if ((j12 < 0).or.(j22 < 0).or.(j32 < 0).or.(abs(m12) > j12).or. &
+ (abs(m22) > j22).or.(abs(m32) > j32)) then
   write(*,*)
   write(*,'("Error(wigner3jf): invalid arguments :")')
   write(*,'("j12 = ",I8," j22 = ",I8," j32 = ",I8)') j12,j22,j32
@@ -41,11 +41,11 @@ if ((j12.lt.0).or.(j22.lt.0).or.(j32.lt.0).or.(abs(m12).gt.j12).or. &
   write(*,*)
   stop
 end if
-if ((j12.eq.0).and.(j22.eq.0).and.(j32.eq.0)) then
+if ((j12 == 0).and.(j22 == 0).and.(j32 == 0)) then
   wigner3jf=1.d0
   return
 end if
-if ((j12.gt.100).or.(j22.gt.100).or.(j32.gt.100)) then
+if ((j12 > 100).or.(j22 > 100).or.(j32 > 100)) then
   write(*,*)
   write(*,'("Error(wigner3jf): angular momenta out of range : ",3I8)') j12, &
    j22,j32
@@ -55,7 +55,7 @@ end if
 jm1=j12+m12
 jm2=j22+m22
 jm3=j32+m32
-if ((mod(jm1,2).ne.0).or.(mod(jm2,2).ne.0).or.(mod(jm3,2).ne.0)) then
+if ((mod(jm1,2) /= 0).or.(mod(jm2,2) /= 0).or.(mod(jm3,2) /= 0)) then
   wigner3jf=0.d0
   return
 end if
@@ -63,15 +63,15 @@ l12=j22-j12+j32
 l22=j12-j22+j32
 l32=j12+j22-j32
 l42=j12+j22+j32
-if ((mod(l12,2).ne.0).or.(mod(l22,2).ne.0).or.(mod(l32,2).ne.0).or. &
- (mod(l42,2).ne.0)) then
+if ((mod(l12,2) /= 0).or.(mod(l22,2) /= 0).or.(mod(l32,2) /= 0).or. &
+ (mod(l42,2) /= 0)) then
   wigner3jf=0.d0
   return
 end if
 l1=l12/2
 l2=l22/2
 l3=l32/2
-if ((m12+m22+m32.ne.0).or.(l1.lt.0).or.(l2.lt.0).or.(l3.lt.0)) then
+if ((m12+m22+m32 /= 0).or.(l1 < 0).or.(l2 < 0).or.(l3 < 0)) then
   wigner3jf=0.d0
   return
 end if
@@ -80,7 +80,7 @@ n2=(j22+m22)/2
 k1=max(0,n1-l2,n2-l1)
 k2=min(l3,n1,n2)
 k=k1+(j22-j12+m32)/2
-if (mod(k,2).ne.0) then
+if (mod(k,2) /= 0) then
   sgn=-1.d0
 else
   sgn=1.d0
@@ -88,7 +88,7 @@ end if
 sm=0.d0
 do k=k1,k2
   t1=sgn*factr(l1,l1-n2+k)*factr(l2,l2-n1+k)*factr(l3,l3-k)
-  sm=sm+t1/(factnm(k,1)*factnm(n1-k,1)*factnm(n2-k,1))
+  sm=sm+t1/(factn(k)*factn(n1-k)*factn(n2-k))
   sgn=-sgn
 end do
 jm1=jm1/2
@@ -98,7 +98,7 @@ t1=factr(jm1,l1)*factr(jm2,l2)*factr(jm3,l3)
 jm1=(j12-m12)/2
 jm2=(j22-m22)/2
 jm3=(j32-m32)/2
-t1=t1*factr(jm3,1+l42/2)*factnm(jm1,1)*factnm(jm2,1)
+t1=t1*factr(jm3,1+l42/2)*factn(jm1)*factn(jm2)
 wigner3jf=sm*sqrt(t1)
 end function
 !EOC
