@@ -11,7 +11,7 @@ implicit none
 integer ispn,jspn,idu
 integer is,ia,ias
 integer k,l,ll,m1,m2,lm1,lm2
-if (dftu.eq.0) return
+if (dftu == 0) return
 ! machine readable density matrix file
 open(50,file='DMATMT'//trim(filext),form='FORMATTED',action='WRITE')
 do idu=1,ndftu
@@ -78,7 +78,7 @@ do idu=1,ndftu
   end do
   write(50,'(G18.10," : U")') ujdu(1,idu)
   write(50,'(G18.10," : J")') ujdu(2,idu)
-  if (inpdftu.ge.4) write(50,'(G18.10," : screening length λ")') lamdu(idu)
+  if (inpdftu >= 4) write(50,'(G18.10," : screening length λ")') lamdu(idu)
 end do
 close(50)
 end subroutine
