@@ -30,14 +30,14 @@ allocate(hmlbse(nmbse,nmbse))
 ! read in BSE Hamiltonian matrix
 open(140,file='HMLBSE.OUT',form='UNFORMATTED',action='READ',status='OLD', &
  iostat=ios)
-if (ios.ne.0) then
+if (ios /= 0) then
   write(*,*)
   write(*,'("Error(writeevbse): error opening HMLBSE.OUT")')
   write(*,*)
   stop
 end if
 read(140) nmbse_
-if (nmbse.ne.nmbse_) then
+if (nmbse /= nmbse_) then
   write(*,*)
   write(*,'("Error(writeevbse): differing nmbse")')
   write(*,'(" current    : ",I6)') nmbse
@@ -47,7 +47,6 @@ if (nmbse.ne.nmbse_) then
 end if
 read(140) hmlbse
 close(140)
-write(*,*)
 write(*,'("Info(writeevbse): diagonalising the BSE Hamiltonian matrix")')
 if (bsefull) then
 ! full non-Hermitian matrix
