@@ -8,7 +8,7 @@ use modmain
 implicit none
 ! local variables
 integer is,ist
-! solve the atomic Dirac-Kohn-Sham ground state for all species
+! solve the atomic Dirac-Kohn-Sham ground-state for all species
 call init0
 ! write out the atomic eigenvalues for each species
 open(50,file='EVALSP.OUT',form='FORMATTED')
@@ -29,6 +29,5 @@ write(*,*)
 write(*,'("Info(writeevsp)")')
 write(*,'(" Kohn-Sham-Dirac eigenvalues written to EVALSP.OUT for all atomic &
  &species")')
-return
 end subroutine
 
