@@ -35,7 +35,7 @@ call genexpmt(1,jlgqr,ylmgq,1,sfacgq,expmt)
 expmt(:,:)=omega*expmt(:,:)
 deallocate(jlgqr,ylmgq,sfacgq)
 ! number of k-points to write out
-if (kstlist(1,1) <= 0) then
+if (kstlist(1,1) < 1) then
   nk=nkpt
 else
   nk=nkstlist
@@ -51,12 +51,12 @@ write(50,'(I8," : number of k-points")') nk
 write(50,'(I6," : number of states per k-point")') nstsv
 allocate(emat(nstsv,nstsv))
 do jk=1,nk
-  if (kstlist(1,1) <= 0) then
+  if (kstlist(1,1) < 1) then
     ik=jk
   else
     ik=kstlist(1,jk)
   end if
-  if ((ik <= 0).or.(ik > nkpt)) then
+  if ((ik < 1).or.(ik > nkpt)) then
     write(*,*)
     write(*,'("Error(writeexpiqr): k-point out of range : ",I8)') ik
     write(*,*)
