@@ -17,10 +17,9 @@ use modmain
 !EOP
 !BOC
 implicit none
-open(50,file='EFERMI'//trim(filext),form='FORMATTED')
+open(50,file='EFERMI'//trim(filext),form='FORMATTED',action='WRITE')
 write(50,'(G18.10)') efermi
 close(50)
-return
 end subroutine
 !EOC
 
