@@ -10,7 +10,6 @@ implicit none
 integer, intent(in) :: fnum
 ! local variables
 integer is,ia,ias
-real(8) t1
 write(fnum,*)
 write(fnum,'("Forces :")')
 do is=1,nspecies
@@ -21,8 +20,7 @@ do is=1,nspecies
     write(fnum,'("   Hellmann-Feynman",T30,": ",3F14.8)') forcehf(:,ias)
     write(fnum,'("   IBS",T30,": ",3F14.8)') forcetot(:,ias)-forcehf(:,ias)
     write(fnum,'("   total force",T30,": ",3F14.8)') forcetot(:,ias)
-    t1=sqrt(forcetot(1,ias)**2+forcetot(2,ias)**2+forcetot(3,ias)**2)
-    write(fnum,'("   total magnitude",T30,": ",F14.8)') t1
+    write(fnum,'("   total magnitude",T30,": ",F14.8)') norm2(forcetot(:,ias))
   end do
 end do
 end subroutine
