@@ -27,7 +27,7 @@ open(50,file='GCLQ'//trim(filext),form='FORMATTED',action='WRITE')
 write(50,'(I6," : nqpt; q-point, vql, gclq, 4π/q² below")') nqpt
 do iq=1,nqpt
   t1=vqc(1,iq)**2+vqc(2,iq)**2+vqc(3,iq)**2
-  if (t1.gt.1.d-12) then
+  if (t1 > 1.d-12) then
     t1=fourpi/t1
   else
     t1=0.d0
