@@ -114,6 +114,9 @@ do is=1,nspecies
 end do
 write(fnum,*)
 write(fnum,'("Total number of atoms per unit cell : ",I4)') natmtot
+write(fnum,'("Total muffin-tin volume : ",G18.10)') omegamt
+write(fnum,'(" ratio of muffin-tin to unit cell volume : ",G18.10)') &
+ omegamt/omega
 write(fnum,*)
 write(fnum,'("Spin treatment :")')
 if (spinpol) then
@@ -252,9 +255,6 @@ end select
 write(fnum,'("Maximum |G+k| for APW functions       : ",G18.10)') gkmax
 write(fnum,'("Maximum (1/2)|G+k|²                   : ",G18.10)') 0.5d0*gkmax**2
 write(fnum,'("Maximum |G| for potential and density : ",G18.10)') gmaxvr
-if (trimvg) then
-  write(fnum,'(" potential will be trimmed for |G| > 2 gkmax")')
-end if
 write(fnum,'("Constant for pseudocharge density : ",I4)') npsd
 write(fnum,'("Radial integration step length : ",I4)') lradstp
 write(fnum,*)
