@@ -7,10 +7,7 @@ subroutine writelat
 use modmain
 implicit none
 open(50,file='LATTICE'//trim(filext),form='FORMATTED',action='WRITE')
-write(50,*)
-write(50,'("+----------------------------+")')
-write(50,'("| Real-space lattice vectors |")')
-write(50,'("+----------------------------+")')
+call writebox(50,"Real-space lattice vectors")
 write(50,*)
 write(50,'("vector a1 : ",3G18.10)') avec(:,1)
 write(50,'("vector a2 : ",3G18.10)') avec(:,2)
@@ -28,10 +25,7 @@ write(50,'(3G18.10)') ainv(3,:)
 write(50,*)
 write(50,'("Unit cell volume : ",G18.10)') omega
 write(50,*)
-write(50,*)
-write(50,'("+----------------------------------+")')
-write(50,'("| Reciprocal-space lattice vectors |")')
-write(50,'("+----------------------------------+")')
+call writebox(50,"Reciprocal-space lattice vectors")
 write(50,*)
 write(50,'("vector b1 : ",3G18.10)') bvec(:,1)
 write(50,'("vector b2 : ",3G18.10)') bvec(:,2)
