@@ -15,9 +15,13 @@ call writew90win
 call writew90eig
 ! call the Wannier90 setup routine
 call setupw90
+! write the .amn file
+call writew90amn
 ! write the .mmn file
 call writew90mmn
 ! write the .spn file
 call writew90spn
+! write the UNK files if required
+if (wrtunk) call writew90unk
 end subroutine
 
