@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU Lesser General Public
 ! License. See the file COPYING for license details.
 
-subroutine x_wc06(rho,s,u,v,ex,vx)
+elemental subroutine x_wc06(rho,s,u,v,ex,vx)
 implicit none
 ! arguments
 real(8), intent(in) :: rho,s,u,v
@@ -39,6 +39,5 @@ fs=2.d0*t1*t3
 fss=t3*(4.d0*t2-8.d0*s*(t1**2)/(kappa*p0))
 ! exchange potential
 vx=exu*(thrd4*fxwc-(u-thrd4*s2*s)*fss-v*fs)
-return
-end
+end subroutine
 
