@@ -22,7 +22,7 @@ call dfftw_execute(plan)
 call dfftw_destroy_plan(plan)
 !$OMP END CRITICAL(fftw_)
 if (sgn == -1) then
-  p=product(n(:))
+  p=product(n(1:nd))
   t1=1.d0/dble(p)
   call zdscal(p,t1,z,1)
 end if
@@ -51,7 +51,7 @@ call dfftw_execute(plan)
 call dfftw_destroy_plan(plan)
 !$OMP END CRITICAL(fftw_)
 if (sgn == -1) then
-  p=product(n(:))
+  p=product(n(1:nd))
   t1=1.d0/dble(p)
   p=p/n(1)
   p=p*(n(1)/2+1)
