@@ -43,9 +43,9 @@ end do
 ! determine the sign from the number of row interchanges
 m=1
 do i=1,n
-  if (ipiv(i).ne.i) m=-m
+  if (ipiv(i) /= i) m=-m
 end do
-if (m.eq.-1) zmdet=-zmdet
+if (m == -1) zmdet=-zmdet
 end function
 !EOC
 
