@@ -40,9 +40,10 @@ complex(8), intent(out) :: zvclmt(*)
 integer nro,iro,ir
 integer l,l1,l2,l3
 integer lm,npi,i0,i
-real(8) r1,r2,t0,t1,t2,t3,t4
+real(8) t0
+complex(8) z1
 ! automatic arrays
-real(8) f1(nr),f2(nr),f3(nr),f4(nr),f5(nr)
+complex(8) f1(nr),f2(nr),f3(nr)
 nro=nr-nri
 iro=nri+1
 npi=lmmaxi*nri
@@ -54,37 +55,25 @@ do l=0,lmaxi
   do lm=l**2+1,(l+1)**2
     do ir=1,nri
       i=lm+lmmaxi*(ir-1)
-      t1=dble(zrhomt(i)); t2=aimag(zrhomt(i))
-      r1=rl(ir,l1); r2=rl(ir,l2)
-      f1(ir)=t1*r1; f2(ir)=t2*r1
-      f3(ir)=t1*r2; f4(ir)=t2*r2
+      f1(ir)=rl(ir,l1)*zrhomt(i)
+      f2(ir)=rl(ir,l2)*zrhomt(i)
     end do
     i0=lm+npi
     do ir=iro,nr
       i=i0+lmmaxo*(ir-iro)
-      t1=dble(zrhomt(i)); t2=aimag(zrhomt(i))
-      r1=rl(ir,l1); r2=rl(ir,l2)
-      f1(ir)=t1*r1; f2(ir)=t2*r1
-      f3(ir)=t1*r2; f4(ir)=t2*r2
+      f1(ir)=rl(ir,l1)*zrhomt(i)
+      f2(ir)=rl(ir,l2)*zrhomt(i)
     end do
-    call splintwp(nr,wpr,f1,f5)
+    call splintwp(nr,wpr,f1,f3)
     call splintwp(nr,wpr,f2,f1)
-    call splintwp(nr,wpr,f3,f2)
-    call splintwp(nr,wpr,f4,f3)
-    t1=f2(nr); t2=f3(nr)
+    z1=f1(nr)
     do ir=1,nri
       i=lm+lmmaxi*(ir-1)
-      r1=t0*rl(ir,l3); r2=t0*rl(ir,l)
-      t3=r1*f5(ir)+r2*(t1-f2(ir))
-      t4=r1*f1(ir)+r2*(t2-f3(ir))
-      zvclmt(i)=cmplx(t3,t4,8)
+      zvclmt(i)=t0*(rl(ir,l3)*f3(ir)+rl(ir,l)*(z1-f1(ir)))
     end do
     do ir=iro,nr
       i=i0+lmmaxo*(ir-iro)
-      r1=t0*rl(ir,l3); r2=t0*rl(ir,l)
-      t3=r1*f5(ir)+r2*(t1-f2(ir))
-      t4=r1*f1(ir)+r2*(t2-f3(ir))
-      zvclmt(i)=cmplx(t3,t4,8)
+      zvclmt(i)=t0*(rl(ir,l3)*f3(ir)+rl(ir,l)*(z1-f1(ir)))
     end do
   end do
 end do
@@ -97,22 +86,15 @@ do l=lmaxi+1,lmaxo
     i0=lm+npi
     do ir=iro,nr
       i=i0+lmmaxo*(ir-iro)
-      t1=dble(zrhomt(i)); t2=aimag(zrhomt(i))
-      r1=rl(ir,l1); r2=rl(ir,l2)
-      f1(ir)=t1*r1; f2(ir)=t2*r1
-      f3(ir)=t1*r2; f4(ir)=t2*r2
+      f1(ir)=rl(ir,l1)*zrhomt(i)
+      f2(ir)=rl(ir,l2)*zrhomt(i)
     end do
-    call splintwp(nro,wpr(1,iro),f1(iro),f5(iro))
+    call splintwp(nro,wpr(1,iro),f1(iro),f3(iro))
     call splintwp(nro,wpr(1,iro),f2(iro),f1(iro))
-    call splintwp(nro,wpr(1,iro),f3(iro),f2(iro))
-    call splintwp(nro,wpr(1,iro),f4(iro),f3(iro))
-    t1=f2(nr); t2=f3(nr)
+    z1=f1(nr)
     do ir=iro,nr
       i=i0+lmmaxo*(ir-iro)
-      r1=t0*rl(ir,l3); r2=t0*rl(ir,l)
-      t3=r1*f5(ir)+r2*(t1-f2(ir))
-      t4=r1*f1(ir)+r2*(t2-f3(ir))
-      zvclmt(i)=cmplx(t3,t4,8)
+      zvclmt(i)=t0*(rl(ir,l3)*f3(ir)+rl(ir,l)*(z1-f1(ir)))
     end do
   end do
 end do
@@ -124,21 +106,22 @@ pure subroutine splintwp(n,wp,f,g)
 implicit none
 ! arguments
 integer, intent(in) :: n
-real(8), intent(in) :: wp(*),f(n)
-real(8), intent(out) :: g(n)
+real(8), intent(in) :: wp(*)
+complex(8), intent(in) :: f(n)
+complex(8), intent(out) :: g(n)
 ! local variables
 integer i,j
-real(8) sm
+complex(8) zsm
 g(1)=0.d0
-sm=wp(5)*f(1)+wp(6)*f(2)+wp(7)*f(3)+wp(8)*f(4)
-g(2)=sm
+zsm=wp(5)*f(1)+wp(6)*f(2)+wp(7)*f(3)+wp(8)*f(4)
+g(2)=zsm
 do i=2,n-2
   j=i*4+1
-  sm=sm+wp(j)*f(i-1)+wp(j+1)*f(i)+wp(j+2)*f(i+1)+wp(j+3)*f(i+2)
-  g(i+1)=sm
+  zsm=zsm+wp(j)*f(i-1)+wp(j+1)*f(i)+wp(j+2)*f(i+1)+wp(j+3)*f(i+2)
+  g(i+1)=zsm
 end do
 j=(n-1)*4+1
-g(n)=sm+wp(j)*f(n-3)+wp(j+1)*f(n-2)+wp(j+2)*f(n-1)+wp(j+3)*f(n)
+g(n)=zsm+wp(j)*f(n-3)+wp(j+1)*f(n-2)+wp(j+2)*f(n-1)+wp(j+3)*f(n)
 end subroutine
 
 end subroutine
