@@ -17,9 +17,9 @@ do is=1,nspecies
   do ia=1,natoms(is)
     ias=idxas(ia,is)
     do i=1,3
-      t1=-datposc(i,0,ia,is)
+      t1=-atdvc(i,0,ia,is)
 ! add the gradient of the Coulomb potential of the nucleus plus static density
-      zvclmt(1:np,ias)=zvclmt(1:np,ias)+t1*gvclns(1:np,i,ias)
+      zvclmt(1:np,ias)=zvclmt(1:np,ias)+t1*gvnsmt(1:np,i,ias)
     end do
   end do
 end do
